@@ -2,7 +2,7 @@
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 #include <unistd.h>
 #include <signal.h>
 #include <stdlib.h>
@@ -21,6 +21,7 @@
 #include <math.h>
 #include "Messagetypes.h"
 
+using namespace std;
 
 
 
@@ -57,9 +58,9 @@ check_messages(int sig)
   char text[81];
   message_to_robot_type msg_t;
 
-  timeval current_time;
-  gettimeofday(&current_time, NULL);
-  srand(current_time.tv_usec);
+  //timeval current_time;
+  //gettimeofday(&current_time, NULL);
+  //srand(current_time.tv_usec);
 
   cin.clear();
   while( !cin.eof() )
