@@ -31,6 +31,8 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <iostream>
 #include <iomanip>
 #include <stdarg.h>
+#include <string>
+using namespace std;
 
 #if HAVE_DIRENT_H
 # include <dirent.h>
@@ -57,7 +59,6 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include "IntlDefs.h"
 #include "Extras.h"
 #include "Various.h"
-#include "String.h"
 #include "Shot.h"
 #include "Options.h"
 #include "Wall.h"
@@ -67,7 +68,11 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 # include "ControlWindow.h"
 # include "MessageWindow.h"
 extern class ControlWindow* controlwindow_p;
-#endif 
+#endif
+
+#ifndef NO_NETWORK
+    #include "ClientInterface.h"
+#endif
 
 ArenaBase::ArenaBase()
 {
@@ -83,9 +88,9 @@ ArenaBase::ArenaBase()
   pause_after_next_game = false;
 
   reset_timer();
-  
-  object_lists[ROBOT].set_deletion_responsibility(false);
-  all_robots_in_sequence.set_deletion_responsibility(false);
+
+  //object_lists[ROBOT].set_deletion_responsibility(false);
+  //all_robots_in_sequence.set_deletion_responsibility(false);
 
   debug_level = 0;
 }
@@ -107,7 +112,7 @@ ArenaBase::set_state( const state_t st )
 #ifndef NO_GRAPHICS
   if( !no_graphics )
     {
-      String infotext;
+      string infotext;
       switch( state )
         {
         case NO_STATE:
@@ -115,38 +120,46 @@ ArenaBase::set_state( const state_t st )
           infotext = "RealTimeBattle";
           break;
         case STARTING_ROBOTS:
-          infotext = "RTB  " + (String)_("*Starting robots*");
+          infotext = "RTB  " + string( _("*Starting robots*") );
           break;
         case SHUTTING_DOWN_ROBOTS:
-          infotext = "RTB  " + (String)_("*Shutting down robots*");
+          infotext = "RTB  " + string( _("*Shutting down robots*") );
           break;
         case BEFORE_GAME_START:
         case GAME_IN_PROGRESS:
-          infotext = "RealTimeBattle  " + (String)_("*Running*");
+          infotext = "RealTimeBattle  " + string( _("*Running*") );
           if( pause_after_next_game )
-            infotext = "RTB  " + (String)_("*Pausing after game*");
+            infotext = "RTB  " + string( _("*Pausing after game*") );
           break;
         case PAUSING_BETWEEN_GAMES:
         case PAUSED:
-          infotext = "RealTimeBattle  " + (String)_("*Paused*");
+          infotext = "RealTimeBattle  " + string( _("*Paused*") );
           break;
         case EXITING:
-          infotext = "RealTimeBattle  " + (String)_("*Exiting*");
+          infotext = "RealTimeBattle  " + string( _("*Exiting*") );
           break;
         case FINISHED:
-          infotext = "RealTimeBattle  " + (String)_("*Finished*");
-          break;
-          
-        default:
+          infotext = "RealTimeBattle  " + string( _("*Finished*") );
+		  #ifndef NO_NETWORK
+          // set ClientInterface to accept new connection
+          try{
+            ClientInterface::Instance()->set_accepting(true);
+          }catch(const bad_exception &e){
+            cerr<< e.what() << endl;
+          }
+          #endif   
+          break;	
+	
+	  default:
           Error(true, "Unknown state", "ArenaBase::set_state");
         }
-      
+
       controlwindow_p->set_window_title( infotext );
     }
-#endif 
+#endif
 }
 
-void 
+void
 ArenaBase::interrupt_tournament()
 {
   if( state == GAME_IN_PROGRESS || state == PAUSED ||
@@ -164,46 +177,45 @@ ArenaBase::interrupt_tournament()
 #endif
 
       delete_lists(true, true, false, true);
-      
+
       set_state( FINISHED );
     }
 }
 
 // This function takes the statistics and saves into a selected file
 void
-ArenaBase::save_statistics_to_file(String filename)
+ArenaBase::save_statistics_to_file(string filename)
 {
-  
-  
-  ofstream file(filename.chars());
+
+
+  ofstream file(filename.c_str());
 
   stat_t* statp;
   Robot* robotp;
 
-  ListIterator<Robot> li;
-  ListIterator<stat_t> stat_li;
-  for(all_robots_in_tournament.first(li); li.ok() ; li++ )
+  list<stat_t*>::const_iterator stat_li;
+  for(list<Robot*>::const_iterator li(all_robots_in_tournament.begin()); li!=all_robots_in_tournament.end() ; ++li )
     {
-      robotp = li();
+      robotp = *li;
       file << robotp->get_robot_name() << ": " << endl;
-      for(robotp->get_statistics()->first(stat_li); stat_li.ok(); stat_li++)
+      for(stat_li = robotp->get_statistics()->begin(); stat_li != robotp->get_statistics()->end(); ++stat_li)
         {
-          statp = stat_li();
-          file << "Seq: " << statp->sequence_nr 
-               << "  Game: " << statp->game_nr 
+          statp = *stat_li;
+          file << "Seq: " << statp->sequence_nr
+               << "  Game: " << statp->game_nr
                << "  Pos: " << statp->position
-               << "  Points: " << statp->points 
+               << "  Points: " << statp->points
                << "  Time Survived: " << statp->time_survived
                << "  Total Points: " << statp->total_points << endl;
         }
     }
-    
-    
+
+
 }
 
 void
-ArenaBase::print_message( const String& messager,
-                          const String& text )
+ArenaBase::print_message( const string& messager,
+                          const string& text )
 {
   if( use_message_file )
     message_file << messager << ": " << text << endl;
@@ -213,7 +225,7 @@ ArenaBase::print_message( const String& messager,
 #endif
 }
 
-void
+bool
 ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, double& angle_factor)
 {
   char text[20];
@@ -231,8 +243,12 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
   file.get(text, 20, ' ');
   if( strcmp(text, "scale" ) == 0 )
     {
-      if( succession != 1 ) Error(true, "Error in arenafile: 'scale' not first", 
-                                  "ArenaBase::parse_arena_line");
+      if( succession != 1 )
+      {
+        Error(false, "Error in arenafile: 'scale' not first",
+                     "ArenaBase::parse_arena_line");
+        return false;
+      }
       succession = 2;
       double scl;
       file >> scl;
@@ -248,14 +264,20 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
       else if( strcmp(unit, "degrees" ) == 0 )
         angle_factor = M_PI / 180.0;
       else
-        Error(true, "Error in arenafile: Unknown angle unit: " + String(unit), 
+      {
+        Error(false, "Error in arenafile: Unknown angle unit: " + string(unit),
               "ArenaBase::parse_arena_line");
+        return false;
+      }
     }
   else if( strcmp(text, "boundary" ) == 0 )
     {
-      if( succession > 2 ) 
-        Error(true, "Error in arenafile: 'boundary' after wallpieces or duplicate", 
+      if( succession > 2 )
+      {
+        Error(false, "Error in arenafile: 'boundary' after wallpieces or duplicate",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
       succession = 3;
       double b1, b2;
       file >> b1;
@@ -264,51 +286,68 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
       file >> b1;
       file >> b2;
       boundary[1] = Vector2D(scale*b1, scale*b2);
-      if( boundary[1][0] - boundary[0][0] <= 0 || 
-          boundary[1][1] - boundary[0][1] <= 0 ) 
-        Error(true, "Error in arenafile: 'boundary' negative", 
+      if( boundary[1][0] - boundary[0][0] <= 0 ||
+          boundary[1][1] - boundary[0][1] <= 0 )
+      {
+        Error(false, "Error in arenafile: 'boundary' negative",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
     }
   else if( strcmp(text, "exclusion_point" ) == 0 )
     {
-      if( succession < 3 ) 
-        Error(true, "Error in arenafile: 'boundary' after wallpieces or duplicate", 
+      if( succession < 3 )
+      {
+        Error(false, "Error in arenafile: 'boundary' after wallpieces or duplicate",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
       file >> vec1;
-      exclusion_points.insert_last(new Vector2D(scale*vec1));
+      exclusion_points.push_back(Vector2D(scale*vec1));
     }
   else if( strcmp(text, "inner_circle" ) == 0 )
     {
-      if( succession < 3 ) 
-        Error(true, "Error in arenafile: 'inner_circle' before boundary", 
+      if( succession < 3 )
+      {
+        Error(false, "Error in arenafile: 'inner_circle' before boundary",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
       succession = 4;
       file >> bounce_c;
       file >> hardn;
       file >> vec1;
       file >> radius;
-      
+
       wall_inner_circlep = new WallInnerCircle(scale*vec1, scale*radius, bounce_c, hardn);
-      object_lists[WALL].insert_first( wall_inner_circlep );
+      //object_lists[WALL].insert_first( wall_inner_circlep );
+      object_lists[WALL].push_front(wall_inner_circlep);
     }
   else if( strcmp(text, "circle" ) == 0 )
     {
-      if( succession < 3 ) 
-        Error(true, "Error in arenafile: 'circle' before 'boundary'", 
+      if( succession < 3 )
+      {
+        Error(false, "Error in arenafile: 'circle' before 'boundary'",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
       succession = 4;
       file >> bounce_c;
       file >> hardn;
       file >> vec1;
       file >> radius;
       wall_circlep = new WallCircle(scale*vec1, scale*radius, bounce_c, hardn);
-      object_lists[WALL].insert_last(wall_circlep);
+      //object_lists[WALL].insert_last(wall_circlep);
+      object_lists[WALL].push_back(wall_circlep);
     }
   else if( strcmp(text, "arc" ) == 0 )
     {
-      if( succession < 3 ) 
-        Error(true, "Error in arenafile: 'arc' before 'boundary'", 
+      if( succession < 3 )
+      {
+        Error(false, "Error in arenafile: 'arc' before 'boundary'",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
       succession = 4;
       double angle1, angle2;
       file >> bounce_c;
@@ -318,38 +357,50 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
       file >> radius2;
       file >> angle1;
       file >> angle2;
-      
-      wall_arcp = new WallArc(scale*center, scale*radius, scale*radius2, 
+
+      wall_arcp = new WallArc(scale*center, scale*radius, scale*radius2,
                               angle1 * angle_factor, angle2 * angle_factor,
                               bounce_c, hardn);
-      object_lists[WALL].insert_last(wall_arcp);
+      //object_lists[WALL].insert_last(wall_arcp);
+      object_lists[WALL].push_back(wall_arcp);
     }
   else if( strcmp(text, "line" ) == 0 )
     {
-      if( succession < 3 ) Error(true, "Error in arenafile: 'line' before 'boundary'",
+      if( succession < 3 )
+      {
+        Error(false, "Error in arenafile: 'line' before 'boundary'",
                                  "ArenaBase::parse_arena_line");
+        return false;
+      }
       succession = 4;
       file >> bounce_c;
       file >> hardn;
-      file >> thickness; 
+      file >> thickness;
       thickness *= 0.5;
       file >> vec1;      // start_point
       file >> vec2;      // end_point
 
 
-      if( length(vec2-vec1) == 0.0 ) 
-        Error(true, "Error in arenafile: Zero length line", 
+      if( length(vec2-vec1) == 0.0 )
+      {
+        Error(false, "Error in arenafile: Zero length line",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
 
-      wall_linep = new WallLine(scale*vec1, unit(vec2-vec1), scale*length(vec2-vec1), 
-                                scale*thickness, bounce_c , hardn);      
-      object_lists[WALL].insert_last( wall_linep );
+      wall_linep = new WallLine(scale*vec1, unit(vec2-vec1), scale*length(vec2-vec1),
+                                scale*thickness, bounce_c , hardn);
+      //object_lists[WALL].insert_last( wall_linep );
+      object_lists[WALL].push_back(wall_linep);
     }
   else if( strcmp(text, "polygon" ) == 0 )
     {
-      if( succession < 3 ) 
-        Error(true, "Error in arenafile: 'polygon' before 'boundary'", 
+      if( succession < 3 )
+      {
+        Error(false, "Error in arenafile: 'polygon' before 'boundary'",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
       succession = 4;
       file >> bounce_c;
       file >> hardn;
@@ -358,30 +409,39 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
       file >> vertices;   // number of vertices
       file >> vec1;      // first point
       wall_circlep = new WallCircle(scale*vec1, scale*thickness, bounce_c, hardn);
-      object_lists[WALL].insert_last( wall_circlep );
+      //object_lists[WALL].insert_last( wall_circlep );
+      object_lists[WALL].push_back(wall_circlep);
 
       for(int i=1; i<vertices; i++)
         {
           vec2 = vec1;
           file >> vec1;      // next point
 
-          if( length(vec2-vec1) == 0.0 ) 
-            Error(true, "Error in arenafile: Zero length line in polygon", 
+          if( length(vec2-vec1) == 0.0 )
+          {
+            Error(false, "Error in arenafile: Zero length line in polygon",
                   "ArenaBase::parse_arena_line");
+            return false;
+          }
 
-          wall_linep = new WallLine(scale*vec2, unit(vec1-vec2), 
-                                    scale*length(vec1-vec2), 
-                                    scale*thickness, bounce_c , hardn);      
-          object_lists[WALL].insert_last( wall_linep );
+          wall_linep = new WallLine(scale*vec2, unit(vec1-vec2),
+                                    scale*length(vec1-vec2),
+                                    scale*thickness, bounce_c , hardn);
+          //object_lists[WALL].insert_last( wall_linep );
+	  object_lists[WALL].push_back(wall_linep);
           wall_circlep = new WallCircle(scale*vec1, scale*thickness, bounce_c, hardn);
-          object_lists[WALL].insert_last( wall_circlep );
+          //object_lists[WALL].insert_last( wall_circlep );
+	  object_lists[WALL].push_back(wall_circlep);
         }
     }
   else if( strcmp(text, "closed_polygon" ) == 0 )
     {
-      if( succession < 3 ) 
-        Error(true, "Error in arenafile: 'closed_polygon' before 'boundary'", 
+      if( succession < 3 )
+      {
+        Error(false, "Error in arenafile: 'closed_polygon' before 'boundary'",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
       succession = 4;
       file >> bounce_c;
       file >> hardn;
@@ -390,7 +450,8 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
       file >> vertices;   // number of vertices
       file >> vec1;      // first point
       wall_circlep = new WallCircle(scale*vec1, scale*thickness, bounce_c, hardn);
-      object_lists[WALL].insert_last( wall_circlep );
+      //object_lists[WALL].insert_last( wall_circlep );
+      object_lists[WALL].push_back(wall_circlep);
       vec0 = vec1;
 
       for(int i=1; i<vertices; i++)
@@ -399,31 +460,43 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
           file >> vec1;      // next point
 
           if( length(vec2-vec1) == 0.0 )
-            Error(true, "Error in arenafile: Line in closed_polygon of zero length", 
+          {
+             Error(false, "Error in arenafile: Line in closed_polygon of zero length",
                   "ArenaBase::parse_arena_line");
-          
-          wall_linep = new WallLine(scale*vec2, unit(vec1-vec2), 
-                                    scale*length(vec1-vec2), 
-                                    scale*thickness, bounce_c , hardn);      
-          object_lists[WALL].insert_last( wall_linep );
+             return false;
+          }
+
+          wall_linep = new WallLine(scale*vec2, unit(vec1-vec2),
+                                    scale*length(vec1-vec2),
+                                    scale*thickness, bounce_c , hardn);
+          //object_lists[WALL].insert_last( wall_linep );
+	  object_lists[WALL].push_back(wall_linep);
           wall_circlep = new WallCircle(scale*vec1, scale*thickness, bounce_c, hardn);
-          object_lists[WALL].insert_last( wall_circlep );
+          //object_lists[WALL].insert_last( wall_circlep );
+	  object_lists[WALL].push_back(wall_circlep);
         }
 
-      if( length(vec0-vec1) == 0.0 ) 
-        Error(true, "Error in arenafile: Last line in closed_polygon of zero length", 
+      if( length(vec0-vec1) == 0.0 )
+      {
+        Error(false, "Error in arenafile: Last line in closed_polygon of zero length",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
 
-      wall_linep = new WallLine(scale*vec1, unit(vec0-vec1), scale*length(vec0-vec1), 
-                                scale*thickness, bounce_c , hardn);      
-      object_lists[WALL].insert_last( wall_linep );
+      wall_linep = new WallLine(scale*vec1, unit(vec0-vec1), scale*length(vec0-vec1),
+                                scale*thickness, bounce_c , hardn);
+      //object_lists[WALL].insert_last( wall_linep );
+      object_lists[WALL].push_back(wall_linep);
     }
 
   else if( strcmp(text, "poly_curve" ) == 0 )
     {
-      if( succession < 3 ) 
-        Error(true, "Error in arenafile: 'closed_polygon' before 'boundary'", 
+      if( succession < 3 )
+      {
+        Error(false, "Error in arenafile: 'closed_polygon' before 'boundary'",
               "ArenaBase::parse_arena_line");
+        return false;
+      }
       succession = 4;
       file >> bounce_c;
       file >> hardn;
@@ -433,16 +506,19 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
       Vector2D current_pos, direction;
       file >> current_pos;      // first point
       wall_circlep = new WallCircle(scale*current_pos, scale*thickness, bounce_c, hardn);
-      object_lists[WALL].insert_last( wall_circlep );
+      //object_lists[WALL].insert_last( wall_circlep );
+      object_lists[WALL].push_back(wall_circlep);
+
+      file >> direction;      // start direction
 
-      file >> direction;      // start direction      
-      
       direction.normalize();
 
-      if( lengthsqr(direction) < 0.01 ) 
-        Error(true, "Error in arenafile: directions must not be zero", 
+      if( lengthsqr(direction) < 0.01 )
+      {
+        Error(false, "Error in arenafile: directions must not be zero",
               "ArenaBase::parse_arena_line");
-
+        return false;
+      }
       vec0 = current_pos;
 
       char c;
@@ -451,32 +527,37 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
       do
         {
           file >> c;
-          
+
           switch( c )
             {
             case 'L':  // line
               file >> len;
               if( len <= 0.0 )
-                Error(true, "Error in arenafile: Line in poly_curve must be positive", 
+              {
+                Error(false, "Error in arenafile: Line in poly_curve must be positive",
                       "ArenaBase::parse_arena_line");
-                
-              wall_linep = new WallLine(scale*current_pos, direction, 
-                                        scale*len, 
-                                        scale*thickness, bounce_c , hardn);      
-              object_lists[WALL].insert_last( wall_linep );
+                return false;
+              }
+
+              wall_linep = new WallLine(scale*current_pos, direction,
+                                        scale*len,
+                                        scale*thickness, bounce_c , hardn);
+              //object_lists[WALL].insert_last( wall_linep );
+	      object_lists[WALL].push_back(wall_linep);
 
               current_pos += len * direction;
-              wall_circlep = new WallCircle(scale*current_pos, scale*thickness, 
+              wall_circlep = new WallCircle(scale*current_pos, scale*thickness,
                                             bounce_c, hardn);
-              object_lists[WALL].insert_last( wall_circlep );
-              
+              //object_lists[WALL].insert_last( wall_circlep );
+	      object_lists[WALL].push_back(wall_circlep);
+
               break;
             case 'A':  // Arc
               file >> angle;
               file >> radius;
 
               angle *= angle_factor;
-              center = current_pos - rotate90( direction ) * radius * sgn( angle );
+              center = current_pos - rotate90( direction ) * radius * sgn_rtb( angle );
               start_angle = vec2angle( current_pos - center );
               current_pos = center + radius * angle2vec( start_angle - angle );
               end_angle = vec2angle( current_pos - center );
@@ -484,46 +565,53 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
               if( angle > 0.0 )
                 { tmp = start_angle; start_angle = end_angle; end_angle = tmp; }
 
-              wall_arcp = new WallArc(scale*center, scale*(radius - thickness), 
-                                      scale*(radius + thickness), 
+              wall_arcp = new WallArc(scale*center, scale*(radius - thickness),
+                                      scale*(radius + thickness),
                                       start_angle, end_angle,
                                       bounce_c, hardn);
 
-              object_lists[WALL].insert_last(wall_arcp);              
+              //object_lists[WALL].insert_last(wall_arcp);
+	      object_lists[WALL].push_back(wall_arcp);
 
 
               direction = rotate(direction, -angle);
 
-              wall_circlep = new WallCircle(scale*current_pos, scale*thickness, 
+              wall_circlep = new WallCircle(scale*current_pos, scale*thickness,
                                             bounce_c, hardn);
-              object_lists[WALL].insert_last( wall_circlep );
+              //object_lists[WALL].insert_last( wall_circlep );
+	      object_lists[WALL].push_back(wall_circlep);
               break;
 
             case 'T':  // Turn
-              file >> angle;              
+              file >> angle;
               direction = rotate( direction, -angle*M_PI/180.0 );
 
               break;
-              
+
             case 'C':   // connect to start point and quit
-              if( length(vec0 - current_pos ) == 0.0 ) 
-                Error(true, "Error in arenafile: Last line in poly_curve of zero length", 
+              if( length(vec0 - current_pos ) == 0.0 )
+              {
+                Error(false, "Error in arenafile: Last line in poly_curve of zero length",
                       "ArenaBase::parse_arena_line");
-              
-              wall_linep = new WallLine(scale*current_pos, unit(vec0-current_pos), 
-                                        scale*length(vec0-current_pos), 
-                                        scale*thickness, bounce_c , hardn);      
-              object_lists[WALL].insert_last( wall_linep );              
+                return false;
+              }
+
+              wall_linep = new WallLine(scale*current_pos, unit(vec0-current_pos),
+                                        scale*length(vec0-current_pos),
+                                        scale*thickness, bounce_c , hardn);
+              //object_lists[WALL].insert_last( wall_linep );
+	      object_lists[WALL].push_back(wall_linep);
 
               finish = true;
               break;
             case 'Q':   // quit
               finish = true;
               break;
-              
+
             default:
-              Error(true, "Incorrect arenafile, unknown command in poly_curve: " 
-                    + (String)c, "ArenaBase::parse_arena_line");
+              Error(false, "Incorrect arenafile, unknown command in poly_curve: "
+                    + string(1,c), "ArenaBase::parse_arena_line");
+              return false;
               break;
             }
         }
@@ -531,35 +619,37 @@ ArenaBase::parse_arena_line(ifstream& file, double& scale, int& succession, doub
     }
 
   else if( text[0] != '\0' )
-    Error(true, "Incorrect arenafile, unknown keyword: " + (String)text, 
+  {
+    Error(false, "Incorrect arenafile, unknown keyword: " + string(text),
           "ArenaBase::parse_arena_line");
+    return false;
+  }
+  return true;
 
 }
 
 
 
 double
-ArenaBase::get_shortest_distance(const Vector2D& pos, const Vector2D& dir, 
-                                  const double size, object_type& closest_shape, 
+ArenaBase::get_shortest_distance(const Vector2D& pos, const Vector2D& dir,
+                                  const double size, object_type& closest_shape,
                                   Shape*& colliding_object, const Robot* the_robot)
 {
-  double dist = infinity;
+  double dist = infinity_rtb;
   double d;
   closest_shape = NOOBJECT;
 
-  ListIterator<Shape> li;
-
   for( int obj_type = ROBOT; obj_type < LAST_OBJECT_TYPE; obj_type++ )
     {
-      for( object_lists[obj_type].first(li); li.ok(); li++)
+      for( list<Shape*>::const_iterator li(object_lists[obj_type].begin()); li!=object_lists[obj_type].end(); ++li)
         {
-          if( obj_type != ROBOT || (Robot*)(li()) != the_robot )
+          if( obj_type != ROBOT || (Robot*)(*li) != the_robot )
             {
-              d = li()->get_distance(pos, dir, size);
+              d = (*li)->get_distance(pos, dir, size);
               if( d < dist)
                 {
                   closest_shape = (object_type)obj_type;
-                  colliding_object = li();
+                  colliding_object = *li;
                   dist = d;
                 }
             }
@@ -572,29 +662,26 @@ ArenaBase::get_shortest_distance(const Vector2D& pos, const Vector2D& dir,
 bool
 ArenaBase::space_available(const Vector2D& pos, const double margin)
 {
-  ListIterator<Shape> li;
-
   for( int obj_type = ROBOT; obj_type < LAST_OBJECT_TYPE; obj_type++ )
     {
-      for( object_lists[obj_type].first(li); li.ok(); li++)
-        if( li()->within_distance(pos, margin) ) return false;
+      for( list<Shape*>::const_iterator li(object_lists[obj_type].begin()); li!=object_lists[obj_type].end(); ++li)
+        if( (*li)->within_distance(pos, margin) ) return false;
     }
 
   // Check if it is possible to see any exclusion_points
-  
+
   Vector2D vec;
   double dist;
   object_type obj_t;
   Shape* shapep;
 
-  ListIterator<Vector2D> li_ex;
-
-  for( exclusion_points.first(li_ex); li_ex.ok(); li_ex++)
+  list<Vector2D>::const_iterator li_ex;
+  for( li_ex = exclusion_points.begin(); li_ex != exclusion_points.end(); ++li_ex)
     {
-      vec = *(li_ex());
+      vec = *li_ex;
       dist = length(vec - pos);
-      if( dist <= margin || 
-          dist <= get_shortest_distance(pos, unit(vec - pos), 0.0, 
+      if( dist <= margin ||
+          dist <= get_shortest_distance(pos, unit(vec - pos), 0.0,
                                         obj_t, shapep, (Robot*)NULL) )
         return false;
     }
@@ -603,10 +690,10 @@ ArenaBase::space_available(const Vector2D& pos, const double margin)
 }
 
 
-double 
-ArenaBase::get_shooting_penalty() 
-{ 
-  return min( the_opts.get_d(OPTION_SHOOTING_PENALTY), 0.5 / (double)robots_left ); 
+double
+ArenaBase::get_shooting_penalty()
+{
+  return min_rtb( the_opts.get_d(OPTION_SHOOTING_PENALTY), 0.5 / (double)robots_left );
 }
 
 
@@ -618,11 +705,11 @@ ArenaBase::update_timer(const double factor)
   current_timer = timer.get();
   double timescale = 1.0;
   if( state == GAME_IN_PROGRESS ) timescale = the_opts.get_d(OPTION_TIMESCALE);
-  timestep = min( (current_timer - last_timer) * timescale, 
+  timestep = min_rtb( (current_timer - last_timer) * timescale,
                   the_opts.get_d(OPTION_MAX_TIMESTEP) );
   total_time += timestep*factor;
 
-  total_time = max(total_time, 0.0);
+  total_time = max_rtb(total_time, 0.0);
 }
 
 void
@@ -640,33 +727,32 @@ ArenaBase::move_shots(const double time_period)
 {
   Shot* shotp;
 
-  ListIterator<Shape> li;
-
-  for( object_lists[SHOT].first(li); li.ok(); li++)
+  for( list<Shape*>::iterator li(object_lists[SHOT].begin()); li!=object_lists[SHOT].end();)
     {
-      shotp = (Shot*)li();
+      shotp = (Shot*)(*li);
 
       if( shotp->is_alive() ) shotp->move(time_period);
 
-      if( !shotp->is_alive() ) object_lists[SHOT].remove(li);
+      if( !shotp->is_alive() ) 
+        li=object_lists[SHOT].erase(li);
+      else
+        ++li;        
     }
 }
 
 void
 ArenaBase::move_shots_no_check(const double time_period)
 {
-  ListIterator<Shape> li;
-
-  for( object_lists[SHOT].first(li); li.ok(); li++)
+  for( list<Shape*>::const_iterator li(object_lists[SHOT].begin()); li!=object_lists[SHOT].end(); ++li)
     {
-      ((Shot*)li())->move_no_check(time_period);
+      ((Shot*)(*li))->move_no_check(time_period);
     }
 }
 
-void 
+void
 ArenaBase::set_game_mode( const enum game_mode_t gm )
 {
-  game_mode = gm; 
+  game_mode = gm;
   if( game_mode == DEBUG_MODE )
     {
       if( debug_level == 0 )
@@ -683,7 +769,7 @@ ArenaBase::set_debug_level( const int new_level)
 {
   if( new_level > max_debug_level || new_level < 0 || new_level == debug_level )
     return debug_level;
-  
+
   debug_level = new_level;
 
   return debug_level;
@@ -694,12 +780,12 @@ ArenaBase::pause_game_toggle()
 {
   if( game_mode != COMPETITION_MODE )
     {
-      if( state == GAME_IN_PROGRESS ) 
+      if( state == GAME_IN_PROGRESS )
         set_state( PAUSED );
-      else if( state == PAUSED ) 
+      else if( state == PAUSED )
         set_state( GAME_IN_PROGRESS );
 
-      halt_next = false; 
+      halt_next = false;
     }
   else
     {
@@ -713,60 +799,64 @@ ArenaBase::step_paused_game()
 {
   if( game_mode == DEBUG_MODE && state == PAUSED )
     {
-      halt_next = true; 
+      halt_next = true;
       set_state( GAME_IN_PROGRESS );
     }
 }
 
 void
-ArenaBase::delete_lists(const bool kill_robots, const bool del_seq_list, 
-                        const bool del_tourn_list, const bool del_arena_filename_list, 
+ArenaBase::delete_lists(const bool kill_robots, const bool del_seq_list,
+                        const bool del_tourn_list, const bool del_arena_filename_list,
                         const bool del_robot_obj_list)
 {
   // clear the lists;
 
   for( int obj_type = ROBOT; obj_type < LAST_OBJECT_TYPE; obj_type++ )
     if( obj_type != ROBOT || del_robot_obj_list )
-      object_lists[obj_type].delete_list();
+      object_lists[obj_type].clear();
 
-  exclusion_points.delete_list();
+  exclusion_points.clear();
 
   if( del_seq_list )
     {
       if( kill_robots )
         {
-          ListIterator<Robot> li;
-          for( all_robots_in_sequence.first(li); li.ok(); li++)
-            li()->kill_process_forcefully();
+          list<Robot*>::const_iterator li;
+          for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li)
+            (*li)->kill_process_forcefully();
         }
-      all_robots_in_sequence.delete_list();
+      all_robots_in_sequence.clear();
     }
 
-  if( del_tourn_list )  all_robots_in_tournament.delete_list();
-  if( del_arena_filename_list ) arena_filenames.delete_list();
+  if( del_tourn_list ) {
+    for(list<Robot*>::iterator li(all_robots_in_tournament.begin()); li!=all_robots_in_tournament.end();++li)
+      delete *li;
+    all_robots_in_tournament.clear();
+  }
+  if( del_arena_filename_list ) arena_filenames.clear();
 }
 
 bool
-ArenaBase::find_object_by_id( const List<Shape>& obj_list, 
-                              ListIterator<Shape>& li,
+ArenaBase::find_object_by_id( list<Shape*>& obj_list,
+                              list<Shape*>::iterator & li,
                               const int obj_id )
 {
-  for( obj_list.first(li); li.ok(); li++)
+  for( li = obj_list.begin(); li != obj_list.end(); ++li)
     {
-      if( li()->get_id() == obj_id ) 
+      if( (*li)->get_id() == obj_id )
         return true;
     }
   return false;
 }
 
 bool
-ArenaBase::find_object_by_id( const List<Robot>& obj_list, 
-                              ListIterator<Robot>& li,
+ArenaBase::find_object_by_id( list<Robot*>& obj_list,
+                              list<Robot*>::iterator & li,
                               const int obj_id )
 {
-  for( obj_list.first(li); li.ok(); li++)
+  for( li = obj_list.begin(); li != obj_list.end(); ++li)
     {
-      if( li()->get_id() == obj_id ) 
+      if( (*li)->get_id() == obj_id )
         return true;
     }
   return false;
