@@ -27,6 +27,8 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <unistd.h>
 #include <stdlib.h>
 #include <iostream>
+#include <sstream>
+#include <string>
 #include <iomanip>
 #include <stdarg.h>
 #include <sys/stat.h>
@@ -43,11 +45,12 @@ using namespace std;
 #include "IntlDefs.h"
 #include "Extras.h"
 #include "Various.h"
-#include "String.h"
 #include "Shot.h"
 #include "Options.h"
 #include "Wall.h"
 #include "Robot.h"
+#include "Broadcast.h"
+
 #ifndef NO_GRAPHICS
 # include "ScoreWindow.h"
 # include "ControlWindow.h"
@@ -58,6 +61,10 @@ using namespace std;
 extern class ControlWindow* controlwindow_p;
 #endif
 
+#ifndef NO_NETWORK
+    #include "ClientInterface.h"
+#endif
+
 ArenaRealTime::ArenaRealTime()
 {
   set_game_mode( (ArenaBase::game_mode_t)the_arena_controller.game_mode );
@@ -66,7 +73,6 @@ ArenaRealTime::ArenaRealTime()
                  the_arena_controller.tournament_filename,
                  the_arena_controller.message_filename,
                  the_arena_controller.option_filename );
-
   robots_in_sequence = NULL;
 }
 
@@ -78,7 +84,12 @@ ArenaRealTime::~ArenaRealTime()
   if( robots_in_sequence != NULL )
     delete robots_in_sequence;
 
-  if( use_log_file && LOG_FILE ) LOG_FILE.close();
+  try{
+    Broadcast::Instance()->finalize();
+  }catch(const bad_exception &e){
+    cerr<< e.what() << endl;
+  }
+
   if( use_message_file && message_file ) message_file.close();
 }
 
@@ -98,39 +109,27 @@ ArenaRealTime::clear()
 }
 
 void
-ArenaRealTime::set_filenames( String& log_fname,
-                              const String& statistics_fname, 
-                              const String& tournament_fname,
-                              String& message_fname,
-                              const String& option_fname )
+ArenaRealTime::set_filenames( string& log_fname,
+                              const string& statistics_fname, 
+                              const string& tournament_fname,
+                              string& message_fname,
+                              const string& option_fname )
 {
   bool log_stdout = false;
 
-  if( log_fname == "" )
-    {
-      use_log_file = false;
+  if( !log_fname.empty() ){
+	if( log_fname=="-" || log_fname=="STDOUT" ){
+		log_stdout = true;
+	}
+
+    try{
+      Broadcast::Instance()->set_logfile(log_fname);
+    }catch(const bad_exception &e){
+      cerr<< e.what() << endl;
     }
-  else if( log_fname == "-" || log_fname == "STDOUT" )  // use stdout as log_file
-    {
-      cout << "Attach -- Muss gefixt werden in ArenaREaltime.cc 113" << endl;
-      //LOG_FILE.attach(STDOUT_FILENO);
-      use_log_file = true;
-      log_stdout = true;
-    }
-  else
-    {
-       //LOG_FILE.open(log_fname.chars(), ios::out, S_IRUSR | S_IWUSR);
-		LOG_FILE.open(log_fname.chars(), ios::out);
-		
-      use_log_file = true;
-      if( !LOG_FILE )
-        {
-          Error( false, "Couldn't open log file. Contuing without log file",
-                 "ArenaRealTime::set_filenames" );
-          use_log_file = false;
-        }
-    }
-  if( message_fname == "" )
+  }
+	
+  if( message_fname.empty() )
     {
       use_message_file = false;
     }
@@ -140,6 +139,7 @@ ArenaRealTime::set_filenames( String& log_fname,
         {
           use_message_file = true;
           //message_file.attach( STDOUT_FILENO );
+	  message_file.ios::rdbuf(cout.rdbuf());
         }
       else
         {
@@ -149,7 +149,7 @@ ArenaRealTime::set_filenames( String& log_fname,
   else
     {
       use_message_file = true;
-      //message_file.open( message_fname.chars(), ios::out, S_IRUSR | S_IWUSR );
+      message_file.open( message_fname.c_str(), ios::out);
       if( !message_file )
         {
           Error( false, "Couldn't open message file. Message file disabled",
@@ -166,32 +166,47 @@ ArenaRealTime::set_filenames( String& log_fname,
   option_file_name = option_fname;
 }
 
-void
-ArenaRealTime::parse_arena_file(String& filename)
+bool
+ArenaRealTime::parse_arena_file(string& filename)
 {
   Vector2D vec1, vec2, vec0;
 
-  ifstream file(filename.chars());
-  if( !file ) Error(true, "Couldn't open arena file" + filename, "ArenaBase::parse_arena_file");
+  ifstream file(filename.c_str());
+  if( !file )
+  {
+    Error(false, "Couldn't open arena file" + filename, "ArenaRealtime::parse_arena_file");
+    return false;
+  }
 
   int succession = 1;
   double scale = the_opts.get_d(OPTION_ARENA_SCALE);
   double angle_factor = 1.0;
   do
     {
-      parse_arena_line(file, scale, succession, angle_factor);
+      if ( !file.good() || !parse_arena_line(file, scale, succession, angle_factor) )
+      {
+          Error(false, "Error parsing arena file " + filename,
+                "ArenaRealtime::parse_arena_file");
+          file.close();
+          return false;
+      }
 
     } while( !file.eof() );
 
   file.close();
 
-  
-  if( use_log_file )      // copy the arena file to the log file
-    {
+
+    try{
+      if(Broadcast::Instance()->is_active()){
       char buffer[500];
       
-      ifstream file(filename.chars());
-      if( !file ) Error(true, "Couldn't open arena file for log file" + filename, "ArenaBase::parse_arena_file");
+      ifstream file(filename.c_str());
+      if( !file )
+      {
+        Error(false, "Couldn't open arena file for log file " + filename,
+              "ArenaRealtime::parse_arena_file");
+        return false;
+      }
   
       do
         {
@@ -201,15 +216,24 @@ ArenaRealTime::parse_arena_file(String& filename)
         } 
       while( buffer[0] != '\0' );
       
+      }
+
+    }catch(const bad_exception &e){
+      cerr<< e.what() << endl;
     }
 
+  return true;
 }
 
 void
-ArenaRealTime::print_to_logfile(const char first_letter ... )
+ArenaRealTime::print_to_logfile(char first_letter ... )
 {
-  if( !use_log_file ) return;
+  try{
+  
+  if(Broadcast::Instance()->is_active()==false) return; // broadcast is inactive
 
+  ostream& bcast = *Broadcast::Instance();
+    
   va_list args;
   va_start(args, first_letter);
 
@@ -220,112 +244,117 @@ ArenaRealTime::print_to_logfile(const char first_letter ... )
       return;
     }
 
-  LOG_FILE << first_letter;
+  bcast << first_letter;
 
   int prec = 2;
-  LOG_FILE << setiosflags(ios::fixed) << setprecision(prec);
+  bcast << setiosflags(ios::fixed) << setprecision(prec);
+  ostringstream hex2string;
 
   switch(first_letter)
     {
     case 'R': // Robot position info
-      LOG_FILE << va_arg(args, int   ) << " ";     // robot id;
-      LOG_FILE << va_arg(args, double) << " ";  // x
-      LOG_FILE << va_arg(args, double) << " ";  // y
-      LOG_FILE << va_arg(args, double) << " ";  // robot angle
-      LOG_FILE << va_arg(args, double) << " ";  // cannon angle
-      LOG_FILE << va_arg(args, double) << " ";  // radar angle
-      LOG_FILE << va_arg(args, double);         // energy
+      bcast << va_arg(args, int   ) << " ";     // robot id;
+      bcast << va_arg(args, double) << " ";  // x
+      bcast << va_arg(args, double) << " ";  // y
+      bcast << va_arg(args, double) << " ";  // robot angle
+      bcast << va_arg(args, double) << " ";  // cannon angle
+      bcast << va_arg(args, double) << " ";  // radar angle
+      bcast << va_arg(args, double);         // energy
       break;
 
     case 'T': // Time
-      LOG_FILE << setprecision(prec+1) << va_arg(args, double);  // time elapsed
+      bcast << setprecision(prec+1) << va_arg(args, double);  // time elapsed
       break;
 
     case 'P': // Print a robot message
-      LOG_FILE << va_arg(args, int   ) << " ";  // robot id
-      LOG_FILE << va_arg(args, char* );         // message to print
+      bcast << va_arg(args, int   ) << " ";  // robot id
+      bcast << va_arg(args, char* );         // message to print
       break;
 
     case 'C': // Cookie
-      LOG_FILE << va_arg(args, int   ) << " ";  // cookie id
-      LOG_FILE << va_arg(args, double) << " ";  // x
-      LOG_FILE << va_arg(args, double);         // y
+      bcast << va_arg(args, int   ) << " ";  // cookie id
+      bcast << va_arg(args, double) << " ";  // x
+      bcast << va_arg(args, double);         // y
       break;
 
     case 'M': // Mine
-      LOG_FILE << va_arg(args, int   ) << " ";  // mine id
-      LOG_FILE << va_arg(args, double) << " ";  // x
-      LOG_FILE << va_arg(args, double);         // y
+      bcast << va_arg(args, int   ) << " ";  // mine id
+      bcast << va_arg(args, double) << " ";  // x
+      bcast << va_arg(args, double);         // y
       break;
 
     case 'S': // Shot
-      LOG_FILE << va_arg(args, int   ) << " ";  // shot id
-      LOG_FILE << va_arg(args, double) << " ";  // x
-      LOG_FILE << va_arg(args, double) << " ";  // y
-      LOG_FILE << setprecision(prec+1) << va_arg(args, double) << " ";  // dx/dt
-      LOG_FILE << setprecision(prec+1) << va_arg(args, double);         // dy/dt
+      bcast << va_arg(args, int   ) << " ";  // shot id
+      bcast << va_arg(args, double) << " ";  // x
+      bcast << va_arg(args, double) << " ";  // y
+      bcast << setprecision(prec+1) << va_arg(args, double) << " ";  // dx/dt
+      bcast << setprecision(prec+1) << va_arg(args, double);         // dy/dt
       break;
       
     case 'D': // Die
       {
         int obj_type = va_arg(args, int  );
-        LOG_FILE << (char)obj_type    << " ";  // object type to kill
-        LOG_FILE << va_arg(args, int) << " ";  // object id
+        bcast << (char)obj_type    << " ";  // object type to kill
+        bcast << va_arg(args, int) << " ";  // object id
         if( obj_type == 'R' )
           {
-            LOG_FILE << setprecision(1) 
+            bcast << setprecision(1) 
                      <<  va_arg(args, double) << " "; // robot points received
-            LOG_FILE << va_arg(args, int);            // position this game
+            bcast << va_arg(args, int);            // position this game
           }
       }
       break;
 
     case 'G': // Game begins
-      LOG_FILE << va_arg(args, int  ) << " ";  // sequence number
-      LOG_FILE << va_arg(args, int  ) << " ";  // game number
+      bcast << va_arg(args, int  ) << " ";  // sequence number
+      bcast << va_arg(args, int  ) << " ";  // game number
       //      LOG_FILE << va_arg(args, char*);         // arena filename
       break;
 
     case 'H': // Header
-      LOG_FILE << va_arg(args, int  ) << " ";  // number of games per sequence
-      LOG_FILE << va_arg(args, int  ) << " ";  // number of robots per sequence
-      LOG_FILE << va_arg(args, int  ) << " ";  // number of sequences
-      LOG_FILE << va_arg(args, int  ) << " ";  // number of robots
+      bcast << va_arg(args, int  ) << " ";  // number of games per sequence
+      bcast << va_arg(args, int  ) << " ";  // number of robots per sequence
+      bcast << va_arg(args, int  ) << " ";  // number of sequences
+      bcast << va_arg(args, int  ) << " ";  // number of robots
       //      LOG_FILE << va_arg(args, char*);         // name of optionfile
       break;
 
     case 'L': // List of robot properties
       {
-        LOG_FILE << va_arg(args, int  ) << " ";  // robot id
-        LOG_FILE << hex2str(va_arg(args, long )) << " ";  // robot colour
+        bcast << va_arg(args, int  ) << " ";  // robot id
+        hex2string << std::hex << va_arg(args, long );
+        bcast << hex2string.str() << " ";
        
-        String name = va_arg(args, char*);   // robot name
+        string name = va_arg(args, char*);   // robot name
         if( name == "" ) name = "Anonymous";
-        LOG_FILE << name;
+        bcast << name;
       }
       break;
 
     case 'A': // Arena file line
-      LOG_FILE << va_arg(args, char*);  // line of arena file
+      bcast << va_arg(args, char*);  // line of arena file
       break;
 
     case 'O':
       {
         char option_type = (char)va_arg(args, int);
-        LOG_FILE << va_arg(args, char*);                        // Option label
+        bcast << va_arg(args, char*);                        // Option label
         switch( option_type )
           {
           case 'D':
-            LOG_FILE << String( va_arg(args, double) ).chars(); // Option value
+            bcast << va_arg(args, double) ; // Option value
             break;
           case 'L':
-            LOG_FILE << String( va_arg(args, long) ).chars();   // Option value
+            bcast << va_arg(args, long);   // Option value
             break;
           case 'H':
-            LOG_FILE << hex2str( va_arg(args, long) ).chars();   // Option value
+            {
+              hex2string << std::hex << va_arg(args, long);
+              bcast << hex2string.str();   // Option value
+            }
             break;
           case 'S':
-            LOG_FILE << String( va_arg(args, char*) ).chars();   // Option value
+            bcast << va_arg(args, char*);   // Option value
             break;
           }
       }
@@ -336,8 +365,12 @@ ArenaRealTime::print_to_logfile(const char first_letter ... )
       break;
     }
 
-  LOG_FILE << endl;
+  bcast << endl;
   va_end(args);
+    
+  }catch(const bad_exception &e){
+    cerr<< e.what() << endl;
+  }   
 }
 
 Vector2D
@@ -354,25 +387,35 @@ ArenaRealTime::broadcast(const message_to_robot_type msg_type ...)
 {
   va_list args;
   va_start(args, msg_type);
-  String str = (String)message_to_robot[msg_type].msg + ' ';
+  string str = string(message_to_robot[msg_type].msg) + " ";
   for(int i=0; i<message_to_robot[msg_type].number_of_args; i++)
     {
+      ostringstream number2string;
       switch(message_to_robot[msg_type].arg_type[i])
         {
         case NONE: 
           Error(true, "Couldn't send message, no arg_type", "ArenaRealTime::broadcast");
           break;
         case INT:
-          str += (String)va_arg(args, int) + ' ';
+          {
+            number2string << va_arg(args, int);
+            str += number2string.str() + " ";
+          }
           break;
         case DOUBLE:
-          str += String(va_arg(args, double), 6) + ' ';
+          {
+            number2string << std::hex << va_arg(args, double);
+            str += number2string.str() + " ";
+          }
           break;
         case STRING:
-          str += (String)va_arg(args, char*) + ' ';
+          str += string(va_arg(args, char*)) + " ";
           break;   
         case HEX:
-          str += hex2str(va_arg(args, int)) + ' ';
+          {
+            number2string << std::hex << va_arg(args, int);
+            str += number2string.str() + " "; 
+          }
           break;
         default:
           Error(true, "Couldn't send message, unknown arg_type", "ArenaRealTime::broadcast");
@@ -380,9 +423,8 @@ ArenaRealTime::broadcast(const message_to_robot_type msg_type ...)
     }
   str += '\n';
 
- ListIterator<Shape> li;
- for( object_lists[ROBOT].first(li); li.ok(); li++ )
-    *(((Robot*)li())->get_outstreamp()) << str;
+ for( list<Shape*>::const_iterator li(object_lists[ROBOT].begin()); li!=object_lists[ROBOT].end(); ++li)
+   *(((Robot*)(*li))->get_outstreamp()) << str;
 }
 
 void
@@ -427,15 +469,23 @@ ArenaRealTime::timeout_function()
       {
         read_robot_messages();
 
-        if( total_time > next_check_time ) start_sequence_follow_up();
+        if( total_time > next_check_time )
+          if( !start_sequence_follow_up() )
+          {
+            Error(false, "Error starting game sequence, ending tournament!", "ArenaRealTime::timeout_function");
+            // Finish tournament
+            game_nr = games_per_sequence;
+            sequence_nr = sequences_in_tournament;
+            end_game();
+          }
       }
       break;
       
     case SHUTTING_DOWN_ROBOTS:
       {     
-        ListIterator<Robot> li;
-        for( all_robots_in_sequence.first(li); li.ok(); li++ )
-          li()->get_messages();
+        list<Robot*>::const_iterator li;
+        for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li )
+          (*li)->get_messages();
         
         if( total_time > next_check_time ) end_sequence_follow_up();
       }
@@ -536,7 +586,7 @@ ArenaRealTime::add_cookie()
   if( !found_space ) return;
 
   Cookie* cookiep = new Cookie(pos, en);
-  object_lists[COOKIE].insert_last( cookiep );
+  object_lists[COOKIE].push_back( cookiep );
 
   print_to_logfile('C', cookiep->get_id(), pos[0], pos[1]);
 }
@@ -560,7 +610,7 @@ ArenaRealTime::add_mine()
   if( !found_space )  return;
 
   Mine* minep = new Mine(pos, en);
-  object_lists[MINE].insert_last( minep );
+  object_lists[MINE].push_back( minep );
 
   print_to_logfile('M', minep->get_id(), pos[0], pos[1]);
 }
@@ -568,12 +618,12 @@ ArenaRealTime::add_mine()
 void
 ArenaRealTime::check_robots()
 {
-  ListIterator<Robot> li;
-  for( all_robots_in_sequence.first(li); li.ok(); li++ )
+  list<Robot*>::const_iterator li;
+  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li )
     {
-      if( li()->is_process_running() )
+      if( (*li)->is_process_running() )
         {
-          li()->check_process();
+          (*li)->check_process();
         }      
     } 
 
@@ -583,11 +633,11 @@ ArenaRealTime::check_robots()
 void
 ArenaRealTime::read_robot_messages()
 {
-  ListIterator<Robot> li;
-  for( all_robots_in_sequence.first(li); li.ok(); li++ )
+  list<Robot*>::const_iterator li;
+  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li )
     {
-      if( li()->is_alive() || state != GAME_IN_PROGRESS )  
-        li()->get_messages();
+      if( (*li)->is_alive() || state != GAME_IN_PROGRESS )  
+        (*li)->get_messages();
     }
 }
 
@@ -598,10 +648,9 @@ ArenaRealTime::update_robots()
 
   robots_killed_this_round = 0;
 
-  ListIterator<Shape> li;
-  for( object_lists[ROBOT].first(li); li.ok(); li++ )
+  for( list<Shape*>::const_iterator li(object_lists[ROBOT].begin()); li!=object_lists[ROBOT].end(); ++li)
     {
-      robotp = (Robot*)li();
+      robotp = (Robot*)(*li);
       if( robotp->is_alive() )
         {
           robotp->update_radar_and_cannon(timestep);  
@@ -613,19 +662,19 @@ ArenaRealTime::update_robots()
     }
 
   // Check if robots have died and send energy level
-
-  for( object_lists[ROBOT].first(li); li.ok(); li++ )
+  for( list<Shape*>::iterator li(object_lists[ROBOT].begin()); li!=object_lists[ROBOT].end();)
     {
-      robotp = (Robot*)li();
+      robotp = (Robot*)(*li);
       if( !robotp->is_alive() ) 
         {
-          object_lists[ROBOT].remove(li);
+          li=object_lists[ROBOT].erase(li);
           robots_killed_this_round++;
         }
       else
         {
           double lvls = (double)the_opts.get_l(OPTION_ROBOT_ENERGY_LEVELS);
           robotp->send_message( ENERGY, rint( robotp->get_energy() / lvls ) * lvls );
+	  ++li;
         }
     }
 
@@ -633,9 +682,9 @@ ArenaRealTime::update_robots()
 
   if( robots_killed_this_round > 0 )
     {
-      for( object_lists[ROBOT].first(li); li.ok(); li++ )
+      for( list<Shape*>::const_iterator li(object_lists[ROBOT].begin()); li!=object_lists[ROBOT].end(); ++li)
         {
-          robotp = (Robot*)li();
+          robotp = (Robot*)(*li);
           //          robotp->add_points(robots_killed_this_round);
 #ifndef NO_GRAPHICS
           if( robots_left < 15 && !no_graphics ) 
@@ -643,17 +692,17 @@ ArenaRealTime::update_robots()
 #endif
         }
 
-      ListIterator<Robot> li2;
-      for( all_robots_in_sequence.first(li2); li2.ok(); li2++ )
-        if( li2()->is_dead_but_stats_not_set() )
-          li2()->set_stats(robots_killed_this_round);
+      list<Robot*>::const_iterator li2;
+      for( li2 = all_robots_in_sequence.begin(); li2 != all_robots_in_sequence.end(); ++li2 )
+        if( (*li2)->is_dead_but_stats_not_set() )
+          (*li2)->set_stats(robots_killed_this_round);
       
       broadcast(ROBOTS_LEFT, robots_left);
     }
 
   
-  for( object_lists[ROBOT].first(li); li.ok(); li++ )
-    ((Robot*)li())->send_signal();
+  for( list<Shape*>::const_iterator li(object_lists[ROBOT].begin()); li!=object_lists[ROBOT].end(); ++li)
+    ((Robot*)(*li))->send_signal();
 }
 
 
@@ -687,13 +736,12 @@ bool
 ArenaRealTime::is_colour_allowed(const long colour, const double min_dist, const Robot* robotp)
 {
   double d;
-  ListIterator<Robot> li;
-
-  for( all_robots_in_sequence.first(li); li.ok(); li++ )
+  list<Robot*>::const_iterator li;
+  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li )
     {
-      if(li() != robotp)
+      if(*li != robotp)
         {
-          d = colour_dist( colour, li()->get_rgb_colour() );
+          d = colour_dist( colour, (*li)->get_rgb_colour() );
           if( d < min_dist ) return false;          
         }
     }
@@ -709,6 +757,18 @@ ArenaRealTime::find_free_colour(const long int home_colour,
                                  const long int away_colour, 
                                  const Robot* robotp, const bool random_colours)
 {  
+  // first check, if Robot is in a team
+  if (robotp->isRobotInTeam()) {
+	  // robot will get the same color as its team mates
+	  list<Robot*>::const_iterator li;
+	  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li )
+	    {
+		if (*li!=robotp && (*li)->is_colour_given() && (*li)->isRobotInTeam() && (*li)->getTeamName()==robotp->getTeamName())
+			return (*li)->get_rgb_colour();
+	    }
+	  
+  }
+
   long int tmp_colour;
 
   for(double min_dist = 0.1; min_dist > 0.01 ; min_dist *= 0.8)
@@ -742,35 +802,53 @@ ArenaRealTime::set_debug_level( const int new_level)
   return debug_level;
 }
 
-void
+bool
 ArenaRealTime::start_game()
 {
   // put the arena together
-
   if( pause_after_next_game )
     {
       set_state( PAUSING_BETWEEN_GAMES );
-      return;
+      return true;
     }  
   
-  current_arena_nr = current_arena_nr % number_of_arenas + 1;
-  
-  String* filename = arena_filenames.get_nth(current_arena_nr);
+  current_arena_nr = current_arena_nr % number_of_arenas+1;
+  string filename;
+  try {
+    filename = arena_filenames.at(current_arena_nr-1);
+  }
+  catch(...) {
+    Error(true, "No such element", "ArenaRealTime::start_game" );
+  }
 
   print_to_logfile('G', sequence_nr, game_nr + 1);
 
-  parse_arena_file(*filename);
+  if ( !parse_arena_file(filename) )
+  {
+    Error(false, "Error parsing arena file " + filename, "ArenaRealTime::start_game");
+    return false;
+  }
 
   int charpos;
-  if( (charpos = filename->find('/',0,true)) != -1 )
-    current_arena_filename = get_segment(*filename, charpos+1, -1);
-  else
-    Error(true, "Incomplete arena file path" + *filename, "ArenaRealTime::start_game");
+  try
+    {
+      if( (charpos = filename.rfind('/',filename.size())) != -1 )
+        current_arena_filename = filename.substr(charpos+1, filename.size()-charpos-1);
+      else
+      {
+        Error(false, "Incomplete arena file path " + filename, "ArenaRealTime::start_game");
+        return false;
+      }
+    }
+  catch(exception& e)
+    {
+      Error(true, e.what(), "ArenaRealTime::start_game");
+    }
 
   char msg[128];
   snprintf( msg, 127, _("Game %d of sequence %d begins on arena"),
             game_nr+1, sequence_nr );
-  print_message( "RealTimeBattle", String(msg) + " " + current_arena_filename );
+  print_message( "RealTimeBattle", string(msg) + " " + current_arena_filename );
 
   // reset some variables
 
@@ -790,10 +868,10 @@ ArenaRealTime::start_game()
   
   set_state( BEFORE_GAME_START );
 
-  ListIterator<Robot> li;
-  for( all_robots_in_sequence.first(li); li.ok(); li++ )
+  list<Robot*>::const_iterator li;
+  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li )
     {
-      robotp = li();
+      robotp = *li;
       robotp->get_messages();
 
       found_space = false;
@@ -803,10 +881,14 @@ ArenaRealTime::start_game()
           found_space = space_available(pos, the_opts.get_d(OPTION_ROBOT_RADIUS)*1.2);
         }
 
-      if( !found_space ) Error(true, "Couldn't find space for all robots", "ArenaRealTime::start_game");
+      if( !found_space )
+      {
+        Error(false, "Couldn't find space for all robots", "ArenaRealTime::start_game");
+        return false;
+      }
       angle = ((double)rand())*2.0*M_PI/RAND_MAX;
       robotp->set_values_before_game(pos, angle);
-      object_lists[ROBOT].insert_last(robotp);
+      object_lists[ROBOT].push_back(robotp);
       robots_left++;
       robotp->live();
     }
@@ -821,10 +903,9 @@ ArenaRealTime::start_game()
   update_count_for_logging = 0;
   print_to_logfile('T', 0.0);
 
-  ListIterator<Shape> li2;
-  for( object_lists[ROBOT].first(li2); li2.ok(); li2++ )
+  for( list<Shape*>::const_iterator li(object_lists[ROBOT].begin()); li!=object_lists[ROBOT].end(); ++li)
     {
-      robotp = (Robot*)li2();
+      robotp = (Robot*)(*li);
       robotp->send_signal();
       robotp->move(0.0);  // To log current position
     }
@@ -847,20 +928,20 @@ ArenaRealTime::start_game()
 
   reset_timer();  // Game starts !
   next_check_time = total_time + the_opts.get_d(OPTION_CHECK_INTERVAL);
+  return true;
 }
 
-void
+bool
 ArenaRealTime::end_game()
 {
   Robot* robotp;
-  ListIterator<Robot> li;
-
   int robots_died_by_timeout = robots_left;
   robots_left = 0;
 
-  for( all_robots_in_sequence.first(li); li.ok(); li++ )
+  list<Robot*>::const_iterator li;
+  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li )
     {
-      robotp = li();
+      robotp = *li;
       if( robotp->is_alive() || robotp->is_dead_but_stats_not_set() )
         {
           robotp->die();
@@ -873,9 +954,12 @@ ArenaRealTime::end_game()
   delete_lists(false, false, false, false);
   
   if(game_nr == games_per_sequence) 
+  {
     end_sequence();
+    return true;
+  }
   else
-    start_game();
+    return start_game();
 }
 
 
@@ -889,19 +973,23 @@ ArenaRealTime::start_sequence()
 
   for(int i=0; i<robots_per_game; i++)
     {
-      all_robots_in_sequence.
-        insert_last( all_robots_in_tournament.
-                     get_nth(robots_in_sequence[sequence_nr][i]));
+      list<Robot*>::const_iterator li(all_robots_in_tournament.begin());
+      for(int index(1); (li!=all_robots_in_tournament.end()) && (index<robots_in_sequence[sequence_nr][i]); ++li)
+        ++index;
+      if( li == all_robots_in_tournament.end() )
+        Error(true, "No such element", "ArenaRealTime::start_sequence");
+        
+      all_robots_in_sequence.push_back( *li);
     }
 
   // execute robot processes
 
 
   Robot* robotp;
-  ListIterator<Robot> li;
-  for( all_robots_in_sequence.first(li); li.ok(); li++ )
+  list<Robot*>::const_iterator li;
+  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li )
     {
-      robotp = li();
+      robotp = *li;
       if( robotp->is_networked() )
         {
           *robotp->get_outstreamp() << "@R" << endl;
@@ -919,35 +1007,36 @@ ArenaRealTime::start_sequence()
   next_check_time = total_time + the_opts.get_d(OPTION_ROBOT_STARTUP_TIME);
 }
 
-void
+bool
 ArenaRealTime::start_sequence_follow_up()
 {
   // check if the process have started correctly
   Robot* robotp = NULL;
 
-  ListIterator<Robot> li;
-  for( all_robots_in_sequence.first(li); li.ok(); li++ )
+  list<Robot*>::iterator li;
+  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); )
     {
-      robotp = li();
+      robotp = *li;
       if( !(robotp->is_networked()) &&
           !(robotp->is_process_running()) ) 
         {
-          all_robots_in_sequence.remove(li);
+          li = all_robots_in_sequence.erase(li);
           robots_left--;
         }
       else
-        {      
+        { 
+          ++li;
           if( !robotp->set_and_get_has_competed() )
             print_to_logfile('L', robotp->get_id(), robotp->get_rgb_colour(), 
-                             robotp->get_robot_name().chars());
+                             robotp->get_robot_name().c_str());
           
           if( !robotp->is_name_given() )
             {
               robotp->send_message(WARNING, NAME_NOT_GIVEN, "");
               char msg[128];
               snprintf( msg, 127, _("Robot with filename %s has not given any name"),
-                        robotp->get_robot_filename().chars() );
-              print_message( "RealTimeBattle", String(msg) );
+                        robotp->get_robot_filename().c_str() );
+              print_message( "RealTimeBattle", string(msg) );
             }
 
           if( !robotp->is_colour_given() )
@@ -959,7 +1048,7 @@ ArenaRealTime::start_sequence_follow_up()
         }
 
     }
-  start_game();
+  return start_game();
 }
 
 void
@@ -967,10 +1056,10 @@ ArenaRealTime::end_sequence()
 {
   // kill all robot processes
 
-  ListIterator<Robot> li;
-  for( all_robots_in_sequence.first(li); li.ok(); li++ )
+  list<Robot*>::const_iterator li;
+  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); ++li )
     {
-      li()->end_process();
+      (*li)->end_process();
     }
 
   // wait a second before checking
@@ -986,13 +1075,13 @@ ArenaRealTime::end_sequence_follow_up()
   
   Robot* robotp;
 
-  ListIterator<Robot> li;
-  for( all_robots_in_sequence.first(li); li.ok(); li++ )
+  list<Robot*>::iterator li;
+  for( li = all_robots_in_sequence.begin(); li != all_robots_in_sequence.end(); )
     {
-      robotp = li();
+      robotp = *li;
       if( robotp->is_process_running() ) robotp->kill_process_forcefully();
       robotp->delete_pipes();
-      all_robots_in_sequence.remove(li);
+      li = all_robots_in_sequence.erase(li);
     }
 
   if( sequence_nr == sequences_in_tournament ) 
@@ -1003,8 +1092,8 @@ ArenaRealTime::end_sequence_follow_up()
 
 void
 ArenaRealTime::start_tournament_from_tournament_file
-( const List<start_tournament_info_t>& robotfilename_list, 
-  const List<start_tournament_info_t>& arenafilename_list, 
+( const list<start_tournament_info_t*>& robotfilename_list, 
+  const list<start_tournament_info_t*>& arenafilename_list, 
   const int robots_p_game, const int games_p_sequence, 
   const int n_o_sequences, ArenaRealTime* ar_p )
 {
@@ -1014,8 +1103,8 @@ ArenaRealTime::start_tournament_from_tournament_file
 
 void
 ArenaRealTime::
-start_tournament(const List<start_tournament_info_t>& robotfilename_list, 
-                 const List<start_tournament_info_t>& arenafilename_list, 
+start_tournament(const list<start_tournament_info_t*>& robotfilename_list, 
+                 const list<start_tournament_info_t*>& arenafilename_list, 
                  const int robots_p_game, 
                  const int games_p_sequence, 
                  const int n_o_sequences)
@@ -1037,30 +1126,30 @@ start_tournament(const List<start_tournament_info_t>& robotfilename_list,
     }
 #endif
 
-  // Create robot classes and put them into the list all_robots_in_tournament
+  // Create robot classes and put them into start_sequencethe list all_robots_in_tournament
 
   number_of_robots = 0;
   robot_count = 0;
   Robot* robotp;
   start_tournament_info_t* infop = NULL;
-  String* stringp;
+  string stringp;
 
-  ListIterator<start_tournament_info_t> li;
-  for( robotfilename_list.first(li); li.ok(); li++ )
+  list<start_tournament_info_t*>::const_iterator li;
+  for( li = robotfilename_list.begin(); li != robotfilename_list.end(); ++li )
     {
-      infop = li();
+      infop = *li;
       robotp = new Robot(infop->filename);
-      all_robots_in_tournament.insert_last( robotp );
+      all_robots_in_tournament.push_back( robotp );
       number_of_robots++;
     }
 
   // Create list of arena filenames
   number_of_arenas = 0;
   
-  for( arenafilename_list.first(li); li.ok(); li++ )
+  for( li = arenafilename_list.begin(); li != arenafilename_list.end(); ++li )
     {
-      stringp = new String(li()->filename);
-      arena_filenames.insert_last( stringp );
+      stringp = string((*li)->filename);
+      arena_filenames.push_back( stringp );
       number_of_arenas++;
     }
 
@@ -1073,7 +1162,7 @@ start_tournament(const List<start_tournament_info_t>& robotfilename_list,
   int complete_rounds = n_o_sequences / games_per_round;
   int rem_games = n_o_sequences % games_per_round;
 
-  robots_in_sequence = new (int*)[n_o_sequences];
+  robots_in_sequence = new int*[n_o_sequences];
   for(int i=0; i<n_o_sequences; i++) robots_in_sequence[i] = new int[robots_per_game];
   
   int current_sequence[robots_per_game];
@@ -1081,7 +1170,6 @@ start_tournament(const List<start_tournament_info_t>& robotfilename_list,
   //  for(int i=0; i<robots_per_game; i++) current_sequence[i] = i+1;
   
   // set complete rounds first
-
   for(int round_nr=0; round_nr < complete_rounds; round_nr++)
     {
       int k, i, j;
@@ -1146,10 +1234,17 @@ start_tournament(const List<start_tournament_info_t>& robotfilename_list,
     }
 
   // set random seed
-
-
   srand(timer.get_random_seed());
 
+  #ifndef NO_NETWORK
+  // set ClientInterface to not accept new connection
+  try{
+    ClientInterface::Instance()->set_accepting(false);
+  }catch(const bad_exception &e){
+      cerr<< e.what() << endl;
+  }
+  #endif   
+	
   // start first sequence
 
   print_to_logfile('H', games_per_sequence, robots_per_game, 
