@@ -30,7 +30,6 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include "Extras.h"
 #include "Robot.h"
 #include "Shot.h"
-#include "String.h"
 #include "Structs.h"
 #include "Vector2D.h"
 
@@ -72,14 +71,14 @@ ArenaWindow::ArenaWindow( const int default_width,
   
   // Zoom buttons
 
-  struct button_t { String label; GtkSignalFunc func; };
+  struct button_t { string label; GtkSignalFunc func; };
 
   struct button_t buttons[] = {
-    { (String)_(" No Zoom ") + (String)"[0] ",
+    { string( _(" No Zoom ") ) + string("[0] "),
       (GtkSignalFunc) ArenaWindow::no_zoom  },
-    { (String)_(" Zoom In ") + (String)"[+] ",
+    { string( _(" Zoom In ") ) + string("[+] "),
       (GtkSignalFunc) ArenaWindow::zoom_in  },
-    { (String)_(" Zoom Out ") + (String)"[-] ",
+    { string( _(" Zoom Out ") ) + string("[-] "),
       (GtkSignalFunc) ArenaWindow::zoom_out } };
 
   GtkWidget* button_table = gtk_table_new( 1, 3, TRUE );
@@ -88,7 +87,7 @@ ArenaWindow::ArenaWindow( const int default_width,
   for( int i=0; i < 3; i++ )
     {
       GtkWidget* button =
-        gtk_button_new_with_label( buttons[i].label.chars() );
+        gtk_button_new_with_label( buttons[i].label.c_str() );
       gtk_signal_connect( GTK_OBJECT( button ), "clicked",
                           buttons[i].func, (gpointer) this );
       gtk_table_attach_defaults( GTK_TABLE( button_table ),
@@ -147,9 +146,9 @@ ArenaWindow::~ArenaWindow()
 void
 ArenaWindow::set_window_title()
 {
-  String title = (String)_("Arena") + "   " +
+  string title = string( _("Arena") ) + "   " +
     the_arena.get_current_arena_filename();
-  gtk_window_set_title( GTK_WINDOW( window_p ), title.chars() );
+  gtk_window_set_title( GTK_WINDOW( window_p ), title.c_str() );
 }
 
 void
@@ -222,20 +221,20 @@ ArenaWindow::draw_everything()
           return;
         }
       
-      List<Shape>* object_lists;
+      list<Shape*>* object_lists;
 
       object_lists = the_arena.get_object_lists();
-      ListIterator<Shape> li;
+      list<Shape*>::iterator li;
 
       // Must begin with innercircles (they are destructive)
       for( int obj_type=WALL; obj_type < LAST_OBJECT_TYPE ; obj_type++) 
         {
-          for( object_lists[obj_type].first(li); li.ok(); li++ )
+          for( li = object_lists[obj_type].begin(); li != object_lists[obj_type].end(); ++li )
             {
               if( !( ( obj_type == MINE || obj_type == COOKIE ) &&
-                     !( (Extras*)li() )->is_alive() ) )
+                     !( (Extras*)(*li) )->is_alive() ) )
                 {
-                  li()->draw_shape( false );
+                  (*li)->draw_shape( false );
                 }
             }
         }
@@ -249,7 +248,7 @@ ArenaWindow::draw_moving_objects( const bool clear_objects_first )
 {
   if( window_shown )
     {
-      List<Shape>* object_lists = the_arena.get_object_lists();
+      list<Shape*>* object_lists = the_arena.get_object_lists();
       Robot* robotp;
 
       if( ( scrolled_window->allocation.width - 24 != scrolled_window_size[0]) ||
@@ -259,15 +258,15 @@ ArenaWindow::draw_moving_objects( const bool clear_objects_first )
           return;
         }
 
-      ListIterator<Shape> li;
-      for( object_lists[SHOT].first(li); li.ok(); li++ )
-        if( ((Shot*)li())->is_alive() )
-          ((Shot*)li())->draw_shape( clear_objects_first );
+      list<Shape*>::iterator li;
+      for( li = object_lists[SHOT].begin(); li != object_lists[SHOT].end(); ++li )
+        if( ((Shot*)(*li))->is_alive() )
+          ((Shot*)(*li))->draw_shape( clear_objects_first );
 
-      ListIterator<Shape> li2;
-      for( object_lists[ROBOT].first(li2); li2.ok(); li2++ )
+      list<Shape*>::iterator li2;
+      for( li2 = object_lists[ROBOT].begin(); li2 != object_lists[ROBOT].end(); ++li2 )
         {
-          robotp = (Robot*)li2();
+          robotp = (Robot*)(*li2);
 
           if( robotp->is_alive() )
             {
