@@ -31,9 +31,10 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include "StatisticsWindow.h"
 #include "StartTournamentWindow.h"
 #include "Dialog.h"
-#include "List.h"
 #include "Options.h"
-#include "String.h"
+
+#include <string>
+using namespace std;
 
 Gui::Gui()
 {
@@ -150,11 +151,11 @@ Gui::open_starttournamentwindow()
         if( the_arena.get_state() != NOT_STARTED &&
             the_arena.get_state() != FINISHED )
           {
-            String info_text = _("This action will kill the current tournament.\n"
-                                 "Do you want to do that?");
-            List<String> string_list;
-            string_list.insert_last( new String( "Yes" ) );
-            string_list.insert_last( new String( "No"  ) );
+            string info_text( _("This action will kill the current tournament.\n"
+                                 "Do you want to do that?"));
+            list<string> string_list;
+            string_list.push_back( string( "Yes" ) );
+            string_list.push_back( string( "No"  ) );
             Dialog( info_text, string_list,
                     (DialogFunction) Gui::kill_and_start_new_tournament );
           }
