@@ -24,6 +24,7 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <fstream>
 #include <math.h>
 #include <stdlib.h>
+#include <sstream>
 
 using namespace std;
 
@@ -47,16 +48,23 @@ using namespace std;
 
 Options::Options()
 {
+
 #ifdef HAVE_LOCALE_H
-  setlocale( LC_MESSAGES, "" );
-  setlocale( LC_NUMERIC, "POSIX" );
+setlocale( LC_MESSAGES, "" );
+setlocale( LC_NUMERIC, "POSIX" );
 #endif
+
+#ifdef ENABLE_NLS
+// allow german umlauts
+bind_textdomain_codeset ("RealTimeBattle", "UTF-8");
 #ifdef RTB_LOCALEDIR
-  bindtextdomain( "RealTimeBattle", RTB_LOCALEDIR );
+bindtextdomain( "RealTimeBattle", RTB_LOCALEDIR );
 #else
-  bindtextdomain( "RealTimeBattle", "/usr/local/share/locale" );
+bindtextdomain( "RealTimeBattle", "/usr/local/share/locale" );
 #endif
-  textdomain( "RealTimeBattle" );
+textdomain( "RealTimeBattle" );
+#endif
+
 
   // Entries are: entry_datatype, page in option, 
   //              default value, max value, min value, 
@@ -82,7 +90,7 @@ Options::Options()
                           _("Slide/brake friction") );
 
   all_long_options[OPTION_SEND_ROBOT_COORDINATES] =
-    option_info_t<long>(ENTRY_INT, PAGE_ENVIRONMENT, 0, 0, 2, 4,
+    option_info_t<long>(ENTRY_INT, PAGE_ENVIRONMENT, 2, 0, 2, 4,
                         true, true, "Send robot coordinates", 
                         _("Send robot coordinates") );
 
@@ -284,7 +292,7 @@ Options::Options()
                           _("Update interval [s]") );
 
   all_double_options[OPTION_ROBOT_STARTUP_TIME] = 
-    option_info_t<double>(ENTRY_DOUBLE, PAGE_TIME, 1.0, 0.050, 1000000.0, 12,
+    option_info_t<double>(ENTRY_DOUBLE, PAGE_TIME, 2.0, 0.050, 1000000.0, 12,
                           false, false, "Robot startup time [s]",
                           _("Robot startup time [s]") );
 
@@ -317,15 +325,21 @@ Options::Options()
                         _("Max robots allowed simultaneously") );
 
   all_string_options[OPTION_ROBOT_SEARCH_PATH] =
-    option_info_t<String>(ENTRY_CHAR, PAGE_MISC, "", "", "", 1000,
+    option_info_t<string>(ENTRY_CHAR, PAGE_MISC, "", "", "", 1000,
                           false, false, "Robot search path", _("Robot search path") );
 
   all_string_options[OPTION_ARENA_SEARCH_PATH] =
-    option_info_t<String>(ENTRY_CHAR, PAGE_MISC, "", "", "", 1000,
+    option_info_t<string>(ENTRY_CHAR, PAGE_MISC, "", "", "", 1000,
                           false, false, "Arena search path", _("Arena search path") );
 
+  char* home_dir;
+  string tmp_dir="/rtb";
+  if( NULL == ( home_dir = getenv("HOME") ) ) 
+	  tmp_dir="/tmp"+tmp_dir;
+  else tmp_dir=home_dir+tmp_dir;
+  	  
   all_string_options[OPTION_TMP_RTB_DIR] =
-    option_info_t<String>(ENTRY_CHAR, PAGE_MISC, "/tmp/rtb", "", "", 1000,
+    option_info_t<string>(ENTRY_CHAR, PAGE_MISC, tmp_dir, "", "", 1000,
                           false, false, "Directory for temporary files",
                           _("Directory for temporary files") );
 
@@ -445,7 +459,7 @@ Options::log_all_options()
   for(int i=0;i<LAST_DOUBLE_OPTION;i++)
     if( all_double_options[i].log_option )
       realtime_arena.print_to_logfile( 'O', (int)'D', 
-                                  (all_double_options[i].label + ":").chars(),
+                                  (all_double_options[i].label + ":").c_str(),
                                   all_double_options[i].value );
                         
   for(int i=0;i<LAST_LONG_OPTION;i++)
@@ -453,18 +467,18 @@ Options::log_all_options()
       {
         if( all_long_options[i].datatype == ENTRY_INT )
           realtime_arena.print_to_logfile( 'O', (int)'L',
-                                      (all_long_options[i].label + ":").chars(),
+                                      (all_long_options[i].label + ":").c_str(),
                                       all_long_options[i].value );
         if( all_long_options[i].datatype == ENTRY_HEX )
           realtime_arena.print_to_logfile( 'O', (int)'H',
-                                      (all_long_options[i].label + ":").chars(),
+                                      (all_long_options[i].label + ":").c_str(),
                                       all_long_options[i].value );
       }
   for(int i=0;i<LAST_STRING_OPTION;i++)
     if( all_string_options[i].log_option )
       realtime_arena.print_to_logfile( 'O', (int)'S',
-                                  (all_string_options[i].label + ":").chars(),
-                                  all_string_options[i].value.chars() );
+                                  (all_string_options[i].label + ":").c_str(),
+                                  all_string_options[i].value.c_str() );
 }
 
 void
@@ -474,18 +488,19 @@ Options::get_options_from_rtbrc()
   if( NULL == ( home_dir = getenv("HOME") ) )
     return;
 
-  String resource_file = String(home_dir) + "/.rtbrc";
+  string resource_file = string(home_dir) + "/.rtbrc";
   read_options_file(resource_file,true);
 }
 
 void
-Options::read_options_file(String file_string, const bool as_default)
+Options::read_options_file(string file_string, const bool as_default)
 {
-  ifstream file(file_string.chars());
+  ifstream file(file_string.c_str());
   if( !file )
     return;
-
-  for(;;)
+  try
+   {
+    for(;;)
     {
       char temp;
       char buffer[1000];
@@ -494,7 +509,7 @@ Options::read_options_file(String file_string, const bool as_default)
       file >> ws;
       file.get(buffer,100,':');
       file.get(temp);
-      String option_name(buffer);
+      string option_name(buffer);
       if(option_name == "")
         break;
 
@@ -504,9 +519,9 @@ Options::read_options_file(String file_string, const bool as_default)
             double option_value;
             file >> option_value;
             //file.get(buffer,100,'\n');
-            option_value = min( option_value,
+            option_value = min_rtb( option_value,
                                 all_double_options[i].max_value );
-            option_value = max( option_value,
+            option_value = max_rtb( option_value,
                                 all_double_options[i].min_value );
             all_double_options[i].value = option_value;
             if(as_default)
@@ -523,17 +538,18 @@ Options::read_options_file(String file_string, const bool as_default)
               file >> option_value;
             if( all_long_options[i].datatype == ENTRY_HEX )
               {
-                String temp_string;
+                string temp_string;
                 file >> temp_string;
-							
+                
                 while( temp_string[0] == ' ' )
-                  temp_string = get_segment(temp_string,1,-1);
-                option_value = str2hex(temp_string);
+                  temp_string = temp_string.substr(1);
+                istringstream string2hex(temp_string);
+                string2hex >> std::hex >> option_value;
               }
             //file.get(buffer,100,'\n');
-            option_value = min( option_value,
+            option_value = min_rtb( option_value,
                                 all_long_options[i].max_value );
-            option_value = max( option_value,
+            option_value = max_rtb( option_value,
                                 all_long_options[i].min_value );
             all_long_options[i].value = option_value;
             if(as_default)
@@ -544,10 +560,10 @@ Options::read_options_file(String file_string, const bool as_default)
       for(int i=0;i<LAST_STRING_OPTION;i++)
         if(option_name == all_string_options[i].label )
           {
-            String option_value;
+            string option_value;
             file >> option_value;
             while( option_value[0] == ' ' )
-              option_value = get_segment(option_value,1,-1);
+              option_value = option_value.substr(1);
             //file.get(buffer,100,'\n');
             all_string_options[i].value = option_value;
             if(as_default)
@@ -558,10 +574,15 @@ Options::read_options_file(String file_string, const bool as_default)
      //   file.get(buffer,1000,'\n');  
 	 
     } 
+   }
+  catch(exception& e)
+    {
+      Error(true, e.what(), "Options::read_options_file");
+    }
 }
 
 void
-Options::save_all_options_to_file(String filename, const bool as_default)
+Options::save_all_options_to_file(string filename, const bool as_default)
 {
   if(as_default)
     {
@@ -569,10 +590,10 @@ Options::save_all_options_to_file(String filename, const bool as_default)
       if( NULL == ( home_dir = getenv("HOME") ) )
         return;
 
-      filename = String(home_dir) + "/.rtbrc";
+      filename = string(home_dir) + "/.rtbrc";
     }
 
-  ofstream file(filename.chars(), ios::out);
+  ofstream file(filename.c_str(), ios::out);
 
   if( !file )
     {
@@ -599,7 +620,9 @@ Options::save_all_options_to_file(String filename, const bool as_default)
 	  }
 	  
       if(all_long_options[i].datatype == ENTRY_HEX){ 
-        file << all_long_options[i].label << ": " << hex2str(all_long_options[i].value) << endl;
+        ostringstream hex2string;
+        hex2string << std::hex << all_long_options[i].value;
+        file << all_long_options[i].label << ": " << hex2string.str() << endl;
 		//cout << all_long_options[i].label << ": " << hex2str(all_long_options[i].value) << endl;
 	  }
     }
@@ -611,7 +634,7 @@ Options::save_all_options_to_file(String filename, const bool as_default)
 }
 
 option_return_t
-Options::get_option_from_string( const String& option_name )
+Options::get_option_from_string( const string& option_name )
 {
   option_return_t result( ENTRY_INT, -1 );
 
