@@ -19,6 +19,7 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include <gtk/gtk.h>
 #include <fstream>
+#include <sstream>
 
 using namespace std;
 
@@ -32,7 +33,6 @@ using namespace std;
 #include "ScoreWindow.h"
 #include "StatisticsWindow.h"
 #include "Options.h"
-#include "String.h"
 #include "Various.h"
 
 extern class Options the_opts;
@@ -81,7 +81,7 @@ OptionsWindow::OptionsWindow( const int default_width,
 
   option_info_t<double>* double_opts = the_opts.get_all_double_options();
   option_info_t<long>* long_opts = the_opts.get_all_long_options();
-  option_info_t<String>* string_opts = the_opts.get_all_string_options();
+  option_info_t<string>* string_opts = the_opts.get_all_string_options();
 
   for( int i=0; i < LAST_PAGE; i++ )
     {
@@ -134,18 +134,20 @@ OptionsWindow::OptionsWindow( const int default_width,
               ( double_opts[opt].max_letters_in_entry );
 
             struct button_t buttons[] = {
-              { (String)_(" Min "), true, (GtkSignalFunc) OptionsWindow::double_min,
+              { string( _(" Min ") ), true, (GtkSignalFunc) OptionsWindow::double_min,
                 (gpointer) &double_opts[opt] },
-              { (String)_(" Def "), true, (GtkSignalFunc) OptionsWindow::double_def,
+              { string( _(" Def ") ), true, (GtkSignalFunc) OptionsWindow::double_def,
                 (gpointer) &double_opts[opt] },
-              { (String)_(" Max "), true, (GtkSignalFunc) OptionsWindow::double_max,
+              { string( _(" Max ") ), true, (GtkSignalFunc) OptionsWindow::double_max,
                 (gpointer) &double_opts[opt] } };
-
+            
+            ostringstream number2string;
+            number2string << double_opts[opt].value;
             add_option_to_notebook( description_table,
                                     entry_table, button_table,
-                                    row, double_opts[opt].translated_label,
+                                    row, string(double_opts[opt].translated_label),
                                     double_opts[opt].entry,
-                                    String( double_opts[opt].value ),
+                                    number2string.str(),
                                     info, buttons );
 
           }
@@ -158,11 +160,17 @@ OptionsWindow::OptionsWindow( const int default_width,
             if( long_opts[opt].min_value < 0.0 )
               sign = true;
 
-            String entry_text;
-            if( long_opts[opt].datatype == ENTRY_INT )
-              entry_text = String( long_opts[opt].value );
-            else if( long_opts[opt].datatype == ENTRY_HEX )
-              entry_text = hex2str( long_opts[opt].value );
+            string entry_text;
+            if( long_opts[opt].datatype == ENTRY_INT ) {
+              ostringstream number2string;
+              number2string << long_opts[opt].value;
+              entry_text = number2string.str();
+            }
+            else if( long_opts[opt].datatype == ENTRY_HEX ) {
+              ostringstream hex2string;
+              hex2string << std::hex << long_opts[opt].value;
+              entry_text = hex2string.str();
+            }
 
             entry_t* info = new entry_t( long_opts[opt].datatype, sign );
 
@@ -171,16 +179,18 @@ OptionsWindow::OptionsWindow( const int default_width,
               ( long_opts[opt].max_letters_in_entry );
 
             struct button_t buttons[] = {
-              { (String)_(" Min "), true, (GtkSignalFunc) OptionsWindow::long_min,
+              { string( _(" Min ") ), true, (GtkSignalFunc) OptionsWindow::long_min,
                 (gpointer) &long_opts[opt] },
-              { (String)_(" Def "), true, (GtkSignalFunc) OptionsWindow::long_def,
+              { string( _(" Def ") ), true, (GtkSignalFunc) OptionsWindow::long_def,
                 (gpointer) &long_opts[opt] },
-              { (String)_(" Max "), true, (GtkSignalFunc) OptionsWindow::long_max,
+              { string( _(" Max ") ), true, (GtkSignalFunc) OptionsWindow::long_max,
                 (gpointer) &long_opts[opt] } };
 
+            ostringstream number2string;
+            number2string << long_opts[opt].translated_label;
             add_option_to_notebook( description_table,
                                     entry_table, button_table,
-                                    row, long_opts[opt].translated_label,
+                                    row, number2string.str(),
                                     long_opts[opt].entry,
                                     entry_text, info, buttons );
 
@@ -197,10 +207,10 @@ OptionsWindow::OptionsWindow( const int default_width,
               ( string_opts[opt].max_letters_in_entry );
 
             struct button_t buttons[] = {
-              { (String)"" , false, (GtkSignalFunc) NULL, (gpointer) NULL },
-              { (String)_(" Def "), true, (GtkSignalFunc) OptionsWindow::string_def,
+              { string(""), false, (GtkSignalFunc) NULL, (gpointer) NULL },
+              { string( _(" Def ") ), true, (GtkSignalFunc) OptionsWindow::string_def,
                 (gpointer) &string_opts[opt] },
-              { (String)"" , false, (GtkSignalFunc) NULL, (gpointer) NULL } };
+              { string("") , false, (GtkSignalFunc) NULL, (gpointer) NULL } };
 
             add_option_to_notebook( description_table,
                                     entry_table, button_table,
@@ -243,25 +253,25 @@ OptionsWindow::OptionsWindow( const int default_width,
   gtk_widget_show( hbox );
 
   struct button_t buttons[] = {
-    { (String)_(" Default "), true, (GtkSignalFunc) OptionsWindow::default_opts,
+    { string( _(" Default ") ), true, (GtkSignalFunc) OptionsWindow::default_opts,
       (gpointer) this },
-    { (String)_(" Load options "), true, (GtkSignalFunc) OptionsWindow::load,
+    { string( _(" Load options ") ), true, (GtkSignalFunc) OptionsWindow::load,
       (gpointer) this },
-    { (String)_(" Save options "), true, (GtkSignalFunc) OptionsWindow::save,
+    { string( _(" Save options ") ), true, (GtkSignalFunc) OptionsWindow::save,
       (gpointer) this },
-    { (String)_(" Save as default "), true, (GtkSignalFunc) OptionsWindow::save_def,
+    { string( _(" Save as default ") ), true, (GtkSignalFunc) OptionsWindow::save_def,
       (gpointer) this },
-    { (String)_(" Apply "), true, (GtkSignalFunc) OptionsWindow::apply,
+    { string( _(" Apply ") ), true, (GtkSignalFunc) OptionsWindow::apply,
       (gpointer) this },
-    { (String)_(" Ok "), true, (GtkSignalFunc) OptionsWindow::ok,
+    { string( _(" Ok ") ), true, (GtkSignalFunc) OptionsWindow::ok,
       (gpointer) this },
-    { (String)_(" Cancel "), true, (GtkSignalFunc) OptionsWindow::cancel,
+    { string( _(" Cancel ") ), true, (GtkSignalFunc) OptionsWindow::cancel,
       (gpointer) this } };
 
   for( int i=0; i<7; i++ )
     {
       GtkWidget* button_w =
-        gtk_button_new_with_label( buttons[i].label.chars() );
+        gtk_button_new_with_label( buttons[i].label.c_str() );
       gtk_signal_connect( GTK_OBJECT( button_w ), "clicked",
                           buttons[i].func, buttons[i].data );
       gtk_box_pack_start( GTK_BOX( hbox ), button_w, TRUE,TRUE, 0 );
@@ -281,21 +291,21 @@ void
 OptionsWindow::add_option_to_notebook( GtkWidget* description_table,
                                        GtkWidget* entry_table,
                                        GtkWidget* button_table,
-                                       int row, String description,
+                                       int row, string description,
                                        GtkWidget* entry,
-                                       String entry_text,
+                                       string entry_text,
                                        entry_t* info,
                                        button_t* buttons )
 {
   GtkWidget* label =
-    gtk_label_new( description.chars() );
+    gtk_label_new( description.c_str() );
   gtk_table_attach_defaults( GTK_TABLE( description_table ),
                              label, 0, 1, row, row + 1 );
   gtk_widget_show( label );
-  
+
   gtk_signal_connect( GTK_OBJECT( entry ), "changed",
                       (GtkSignalFunc) entry_handler, info);
-  gtk_entry_set_text( GTK_ENTRY( entry ), entry_text.chars() );
+  gtk_entry_set_text( GTK_ENTRY( entry ), entry_text.c_str() );
   gtk_widget_set_usize( entry, 112, 22 );
   gtk_table_attach_defaults( GTK_TABLE( entry_table ),
                              entry, 0, 1, row, row + 1 );
@@ -305,7 +315,7 @@ OptionsWindow::add_option_to_notebook( GtkWidget* description_table,
   for( int i=0; i<3; i++ )
     if( buttons[i].used )
       {
-        button_w = gtk_button_new_with_label( buttons[i].label.chars() );
+        button_w = gtk_button_new_with_label( buttons[i].label.c_str() );
         gtk_signal_connect( GTK_OBJECT( button_w ), "clicked",
                             buttons[i].func, buttons[i].data );
         gtk_table_attach_defaults( GTK_TABLE( button_table ), button_w,
@@ -318,6 +328,7 @@ void
 OptionsWindow::set_all_options()
 {
   bool allowed = false;
+  istringstream string2number;
 
   if( the_arena_controller.is_started() )
     {
@@ -332,13 +343,15 @@ OptionsWindow::set_all_options()
     {
       option_info_t<double>* double_opts = the_opts.get_all_double_options();
       option_info_t<long>* long_opts = the_opts.get_all_long_options();
-      option_info_t<String>* string_opts = the_opts.get_all_string_options();
+      option_info_t<string>* string_opts = the_opts.get_all_string_options();
       for(int i=0;i<LAST_DOUBLE_OPTION;i++)
         {
-			
-		double entry_value = str2dbl
-            ( gtk_entry_get_text( GTK_ENTRY( double_opts[i].entry ) ) );
-			
+
+          string2number.clear();
+          string2number.str(gtk_entry_get_text( GTK_ENTRY( double_opts[i].entry ) ) );
+          double entry_value;
+          string2number >> entry_value;
+
           if( entry_value > double_opts[i].max_value )
             entry_value = double_opts[i].max_value;
           if( entry_value < double_opts[i].min_value )
@@ -351,11 +364,17 @@ OptionsWindow::set_all_options()
         {
           long entry_value = 0;
           if( long_opts[i].datatype == ENTRY_INT )
-            entry_value = str2long
-              ( gtk_entry_get_text( GTK_ENTRY( long_opts[i].entry ) ) );
+            {
+              string2number.clear();
+              string2number.str(gtk_entry_get_text( GTK_ENTRY( long_opts[i].entry ) ));
+              string2number >> entry_value;
+            }
           if( long_opts[i].datatype == ENTRY_HEX )
-            entry_value = str2hex
-              ( gtk_entry_get_text( GTK_ENTRY( long_opts[i].entry ) ) );
+            {
+              string2number.clear();
+              string2number.str(gtk_entry_get_text( GTK_ENTRY( long_opts[i].entry ) ));
+              string2number >> std::hex >> entry_value >> std::dec;
+            }
 
           if( entry_value > long_opts[i].max_value )
             entry_value = long_opts[i].max_value;
@@ -381,25 +400,34 @@ OptionsWindow::update_all_gtk_entries()
 {
   option_info_t<double>* double_opts = the_opts.get_all_double_options();
   option_info_t<long>* long_opts = the_opts.get_all_long_options();
-  option_info_t<String>* string_opts = the_opts.get_all_string_options();
+  option_info_t<string>* string_opts = the_opts.get_all_string_options();
 
   for(int i=0;i<LAST_DOUBLE_OPTION;i++)
-	  {
-    gtk_entry_set_text( GTK_ENTRY( double_opts[i].entry ),
-                        String(double_opts[i].value).chars() );
-  		}
+    {
+      ostringstream number2string;
+      number2string << double_opts[i].value;
+      gtk_entry_set_text( GTK_ENTRY( double_opts[i].entry ),
+                        number2string.str().c_str() );
+    }
   for(int i=0;i<LAST_LONG_OPTION;i++)
     {
-      if( long_opts[i].datatype == ENTRY_INT )
+      if( long_opts[i].datatype == ENTRY_INT ) 
+      {
+        ostringstream number2string;
+        number2string << long_opts[i].value;
         gtk_entry_set_text( GTK_ENTRY( long_opts[i].entry ),
-                            String( long_opts[i].value).chars() );
-      else if (long_opts[i].datatype == ENTRY_HEX)
+                            number2string.str().c_str() );
+      }
+      else if (long_opts[i].datatype == ENTRY_HEX) {
+        ostringstream hex2string;
+        hex2string << std::hex << long_opts[i].value;
         gtk_entry_set_text( GTK_ENTRY( long_opts[i].entry ),
-                            hex2str(long_opts[i].value).chars() );
+                            hex2string.str().c_str() );
+      }
     }
   for(int i=0;i<LAST_STRING_OPTION;i++)
     gtk_entry_set_text( GTK_ENTRY( string_opts[i].entry ),
-                        string_opts[i].value.chars() );
+                        string_opts[i].value.c_str() );
 }
 
 void
@@ -408,7 +436,7 @@ OptionsWindow::default_opts( GtkWidget* widget,
 {
   option_info_t<double>* double_opts = the_opts.get_all_double_options();
   option_info_t<long>* long_opts = the_opts.get_all_long_options();
-  option_info_t<String>* string_opts = the_opts.get_all_string_options();
+  option_info_t<string>* string_opts = the_opts.get_all_string_options();
 
   for(int i=0;i<LAST_DOUBLE_OPTION;i++)
     double_opts[i].value = double_opts[i].default_value;
@@ -611,24 +639,30 @@ void
 OptionsWindow::double_min( GtkWidget* widget,
                            option_info_t<double>* option )
 {
+  ostringstream number2string;
+  number2string << option->min_value;
   gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                      String( option->min_value ).chars() );
+                      number2string.str().c_str() );
 }
 
 void
 OptionsWindow::double_def( GtkWidget* widget,
                            option_info_t<double>* option )
 {
+  ostringstream number2string;
+  number2string << option->default_value;
   gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                      String( option->default_value ).chars() );
+                      number2string.str().c_str() );
 }
 
 void
 OptionsWindow::double_max( GtkWidget* widget,
                            option_info_t<double>* option )
 {
+  ostringstream number2string;
+  number2string << option->max_value;
   gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                      String( option->max_value ).chars() );
+                      number2string.str().c_str() );
 }
 
 void
@@ -636,11 +670,18 @@ OptionsWindow::long_min( GtkWidget* widget,
                          option_info_t<long>* option )
 {
   if( option->datatype == ENTRY_INT )
+  {
+    ostringstream number2string;
+    number2string << option->min_value;
     gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                        String( option->min_value).chars() );
-  else if( option->datatype == ENTRY_HEX )
+                        number2string.str().c_str() );
+  }
+  else if( option->datatype == ENTRY_HEX ) {
+    ostringstream hex2string;
+    hex2string << std::hex << option->min_value;
     gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                        hex2str( option->min_value).chars() );
+                        hex2string.str().c_str() );
+  }
 }
 
 void
@@ -648,11 +689,18 @@ OptionsWindow::long_def( GtkWidget* widget,
                          option_info_t<long>* option )
 {
   if( option->datatype == ENTRY_INT )
+  {
+    ostringstream number2string;
+    number2string << option->default_value;
     gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                        String( option->default_value).chars() );
-  else if( option->datatype == ENTRY_HEX )
+                        number2string.str().c_str() );
+  }
+  else if( option->datatype == ENTRY_HEX ) {
+    ostringstream hex2string;
+    hex2string << std::hex << option->default_value;
     gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                        hex2str( option->default_value).chars() );
+                        hex2string.str().c_str() );
+  }
 }
 
 void
@@ -660,17 +708,24 @@ OptionsWindow::long_max( GtkWidget* widget,
                          option_info_t<long>* option )
 {
   if( option->datatype == ENTRY_INT )
+  {
+    ostringstream number2string;
+    number2string << option->max_value;
     gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                        String( option->max_value).chars() );
-  else if( option->datatype == ENTRY_HEX )
+                        number2string.str().c_str() );
+  }
+  else if( option->datatype == ENTRY_HEX ) {
+    ostringstream hex2string;
+    hex2string << std::hex << option->max_value;
     gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                        hex2str( option->max_value).chars() );
+                        hex2string.str().c_str() );
+  }
 }
 
 void
 OptionsWindow::string_def( GtkWidget* widget,
-                           option_info_t<String>* option )
+                           option_info_t<string>* option )
 {
   gtk_entry_set_text( GTK_ENTRY( option->entry ),
-                      option->default_value.chars() );
+                      option->default_value.c_str() );
 }
