@@ -25,9 +25,6 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include <unistd.h>
 #include <signal.h>
 #include <iostream>
-#include <fstream>
-#include <sstream>
-#include <string>
 #include <math.h>
 
 using namespace std;
@@ -147,6 +144,8 @@ Robot::Robot(const int r_id, const long int col, const string& name)
   radius = the_opts.get_d(OPTION_ROBOT_RADIUS);
 }
 
+// attribute is set to true in the parent processs
+bool Robot::kill_robots(true);
 
 Robot::~Robot()
 {
@@ -186,6 +185,8 @@ Robot::start_process()
 
   if(pid == 0)   // Child process, to be the new robot
     {
+      // we are the child process, so if we die before execution of another image, we should not kill the other robots
+      kill_robots=false;
       // Make pipe_out the standard input for the robot
       close(pipe_out[1]);
       dup2(pipe_out[0], STDIN_FILENO);
@@ -287,6 +288,7 @@ Robot::start_process()
 
       // Execute process. Should not return!
       if( execl(robot_filename.c_str(), robot_filename.c_str(), NULL) == -1 )
+	// we are in another process so exiting does not solve the problem
         Error(true, "Couldn't open robot " + robot_filename, 
             "Robot::start_process, child");
 
@@ -468,13 +470,16 @@ Robot::send_signal()
 void
 Robot::kill_process_forcefully()
 {
-  if( network_robot )
-    *outstreamp << "@K" << endl;
-  else if( pid > 0 )
-    kill(pid, SIGKILL);
+  // only kill robots if we are the parent process
+  if (kill_robots) {
+	  if( network_robot )
+	    *outstreamp << "@K" << endl;
+	  else if( pid > 0 )
+	    kill(pid, SIGKILL);
 
-  delete_pipes();
-  process_running = false;
+	  delete_pipes();
+	  process_running = false;
+  }
 }
 
 void
@@ -1100,46 +1105,57 @@ Robot::get_messages()
   char msg_name[81];
   message_from_robot_type msg_t;
 
-  *instreamp >> ws;
+  // input stream is set to good status again
   instreamp->clear();
   instreamp->peek();
+  if (!instreamp->good())
+  	return;
+	 
+  // we read 4k at maximum at a turn to avoid the situation where a robot do not stop sending junk 
+  // in order to stop other robot messages from beeing processed
+  instreamp->read(streambuffer,4096);
+  bufferstreamstring.assign(streambuffer,instreamp->gcount());
+  bufferstream.clear();
+  bufferstream.str(bufferstreamstring);
+  bufferstream >> ws;
 
-
-
-  while( !(*instreamp >> msg_name).eof() )
+// super buffer overflow possibility
+//  while( !(*instreamp >> msg_name).eof() )
+while( bufferstream.peek()!=istringstream::traits_type::eof())
     {
+	bufferstream.get(msg_name,80,' ');    
 
 
-      //*instreamp >> msg_name;
+      //bufferstream >> msg_name;
       msg_t = name2msg_from_robot_type(msg_name);
-      //      cerr << "Got message: " << msg_name << endl;
+      // cerr << "Got message: " << msg_name << endl;
 
 
 
-      *instreamp >> ws;
+      bufferstream >> ws;
 
       switch(msg_t)
         {
         case UNKNOWN_MESSAGE_FROM_ROBOT:
           //cout << "Server: Warning sent for message: " << msg_name << endl;
           send_message(WARNING, UNKNOWN_MESSAGE, msg_name);
-          instreamp->get(buffer, 80, '\n');
+          bufferstream.get(buffer, 80, '\n');
           break;
         case ROBOT_OPTION:
           if( check_state_for_message(msg_t, STARTING_ROBOTS) )
             {
               int opt_nr, val;
-              *instreamp >> opt_nr;
+              bufferstream >> opt_nr;
               switch(opt_nr)
                 {
                 case SEND_SIGNAL:
-                  *instreamp >> val;
+                  bufferstream >> val;
                   send_usr_signal = (val == true);
                   signal_to_send = SIGUSR1;
                   send_signal();
                   break;
                 case SIGNAL:
-                  *instreamp >> val;
+                  bufferstream >> val;
                   if( val > 0 && val < NSIG )
                     {
                       signal_to_send = val;
@@ -1156,14 +1172,14 @@ Robot::get_messages()
                   break;
 
                 case SEND_ROTATION_REACHED:
-                  *instreamp >> val;
+                  bufferstream >> val;
                   if( val < 0 ) val = 0;
                   if( val > 2 ) val = 2;
                   send_rotation_reached = val;
                   break;
 
                 case USE_NON_BLOCKING:
-                  *instreamp >> val;
+                  bufferstream >> val;
                   if( network_robot )
                     {
                       *outstreamp << '@' << ( val ? 'N' : 'B' ) << endl;
@@ -1182,7 +1198,7 @@ Robot::get_messages()
         case NAME:
           if( check_state_for_message(msg_t, STARTING_ROBOTS) )
             {
-              instreamp->get(text, 80, '\n');
+              bufferstream.get(text, 80, '\n');
               plain_robot_name = text;
 	      // Here I will insert the team code
 	      string::size_type position=plain_robot_name.rfind("Team: "); 
@@ -1200,7 +1216,7 @@ Robot::get_messages()
             {
               long home_colour, away_colour;
 
-              *instreamp >> std::hex >> home_colour >> away_colour >> std::dec;
+              bufferstream >> std::hex >> home_colour >> away_colour >> std::dec;
 
               // TODO: check if colour is already allocated!
               set_colour( realtime_arena.find_free_colour(home_colour, away_colour, this) );
@@ -1212,7 +1228,7 @@ Robot::get_messages()
             {
               int bits;
               double rot_speed;
-              *instreamp >> bits >> rot_speed;
+              bufferstream >> bits >> rot_speed;
 
               double rot_sign = sgn_rtb(rot_speed);
               rot_speed = fabs(rot_speed);
@@ -1238,7 +1254,7 @@ Robot::get_messages()
             {
               int bits;
               double rot_speed, rot_end_angle, rot_amount;
-              *instreamp >> bits >> rot_speed >> rot_end_angle;
+              bufferstream >> bits >> rot_speed >> rot_end_angle;
               rot_end_angle = max_rtb(min_rtb(rot_end_angle, infinity_rtb), -infinity_rtb);
 
               rot_speed = fabs(rot_speed);
@@ -1279,7 +1295,7 @@ Robot::get_messages()
             {
               int bits;
               double rot_speed, rot_amount;
-              *instreamp >> bits >> rot_speed >> rot_amount;
+              bufferstream >> bits >> rot_speed >> rot_amount;
 
               rot_speed = fabs(rot_speed);
               if( bits & 1 ) rot_speed = min_rtb( rot_speed, the_opts.get_d(OPTION_ROBOT_MAX_ROTATE) );
@@ -1326,7 +1342,7 @@ Robot::get_messages()
             {
               int bits;
               double rot_speed, sweep_left, sweep_right;
-              *instreamp >> bits >> rot_speed >> sweep_left >> sweep_right;
+              bufferstream >> bits >> rot_speed >> sweep_left >> sweep_right;
               sweep_left = max_rtb(min_rtb(sweep_left, infinity_rtb), -infinity_rtb);
               sweep_right = max_rtb(min_rtb(sweep_right, infinity_rtb), -infinity_rtb);
               rotation_mode_t rot_dir;
@@ -1369,7 +1385,7 @@ Robot::get_messages()
           break;
         case PRINT:
           {
-            instreamp->get(text, 160, '\n');
+            bufferstream.get(text, 160, '\n');
             realtime_arena.print_to_logfile('P', id, text);
             the_arena.print_message( robot_name, text );
           }
@@ -1377,7 +1393,7 @@ Robot::get_messages()
 
         case DEBUG:
           {
-            instreamp->get(text, 160, '\n');
+            bufferstream.get(text, 160, '\n');
             if( realtime_arena.get_game_mode() == ArenaBase::DEBUG_MODE )
               {
                 realtime_arena.print_to_logfile('P', id, text);
@@ -1398,7 +1414,7 @@ Robot::get_messages()
               else if( !no_graphics )
                 {
                   double a1, d1, a2, d2;
-                  *instreamp >> a1 >> d1 >> a2 >> d2;
+                  bufferstream >> a1 >> d1 >> a2 >> d2;
 
                   Vector2D start = d1 * angle2vec(a1 + robot_angle.pos);
                   Vector2D direction = d2 * angle2vec(a2 + robot_angle.pos) - start;
@@ -1422,7 +1438,7 @@ Robot::get_messages()
               else if( !no_graphics )
                 {
                   double a, d, r;
-                  *instreamp >> a >> d >> r;
+                  bufferstream >> a >> d >> r;
 
                   Vector2D c = d * angle2vec(a + robot_angle.pos) + center;
 
@@ -1437,7 +1453,7 @@ Robot::get_messages()
           if( check_state_for_message(msg_t, GAME_IN_PROGRESS) )
             {
               double en;
-              *instreamp >> en;
+              bufferstream >> en;
               en = min_rtb(en, shot_energy);
               if( en < the_opts.get_d(OPTION_SHOT_MIN_ENERGY) ) break;
               shot_energy -= en;
@@ -1508,7 +1524,7 @@ Robot::get_messages()
           if( check_state_for_message(msg_t, GAME_IN_PROGRESS) )
             {
               double acc;
-              *instreamp >> acc;
+              bufferstream >> acc;
               acc = max_rtb( acc, the_opts.get_d(OPTION_ROBOT_MIN_ACCELERATION) );
               acc = min_rtb( acc, the_opts.get_d(OPTION_ROBOT_MAX_ACCELERATION) );
               acceleration = acc;
@@ -1520,7 +1536,7 @@ Robot::get_messages()
           if( check_state_for_message(msg_t, GAME_IN_PROGRESS) )
             {
               double brk;
-              *instreamp >> brk;
+              bufferstream >> brk;
               brk = max_rtb( brk, 0.0);
               brk = min_rtb( brk, 1.0);
               brake_percent = brk;
@@ -1530,7 +1546,7 @@ Robot::get_messages()
           //            if( check_state_for_message(msg_t, STARTING_ROBOTS) )
           //              {
           //                bool bin;
-          //                *instreamp >> bin;
+          //                bufferstream >> bin;
           //                load_data(bin);
           //              }
           //            break;
@@ -1559,9 +1575,7 @@ Robot::get_messages()
           Error(true, "Message_type not implemented, " + string(msg_name), "Robot::get_messages");
         }
 
-      *instreamp >> ws;
-      instreamp->clear();
-      instreamp->peek();
+      bufferstream >> ws;
     }
 
 
