@@ -22,7 +22,9 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #endif
 
 #include <math.h>
-#include <iostream.h>
+#include <iostream>
+
+using namespace std;
 
 //#include "Gui.h"
 #include "Shape.h"
@@ -59,6 +61,4 @@ Shape::set_colour(const GdkColor& colour)
   rgb_colour = gdk2hex_colour( colour );
 }
 
-#endif NO_GRAPHICS
-
-
+#endif
