@@ -31,7 +31,7 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include "Options.h"
 
 Shot::Shot(const Vector2D& c, //const double r, 
-           const Vector2D& vel, const double en, const int shot_id = -1 ) 
+           const Vector2D& vel, const double en, const int shot_id) 
   : MovingObject(c, the_opts.get_d(OPTION_SHOT_RADIUS), vel)
 {
   alive = true;
