@@ -49,13 +49,15 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include "IntlDefs.h"
 #include "ArenaRealTime.h"
 #include "StartTournamentWindow.h"
-#include "String.h"
 #include "Various.h"
-#include "List.h"
 #include "Dialog.h"
 #include "Options.h"
 
-const String tmp_tournament_file( "/tmp.tour" );
+#include <string>
+#include <sstream>
+using namespace std;
+
+const string tmp_tournament_file( "/tmp.tour" );
 
 StartTournamentWindow::StartTournamentWindow( const int default_width,
                                               const int default_height,
@@ -90,8 +92,8 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
 
   // Lists for clists
 
-  List<String> robotdirs;
-  List<String> arenadirs;
+  list<string> robotdirs;
+  list<string> arenadirs;
 
   read_dirs_from_system( robotdirs, arenadirs );
 
@@ -105,8 +107,8 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
 
   for( int j = 0; j < 2; j++ )
     {
-      List<start_tournament_info_t>* tour_list;
-      List<start_tournament_info_t>* dir_list;
+      list<start_tournament_info_t*>* tour_list;
+      list<start_tournament_info_t*>* dir_list;
       GtkWidget* tour_clist;
       GtkWidget* dir_clist;
       char** tour_title;
@@ -180,28 +182,31 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
 
       add_clist( dir_clist, hbox );
 
-      ListIterator<String> li;
+      list<string>::const_iterator li;
 
       if( robot )
-        robotdirs.first(li);
+        li = robotdirs.begin();
       else
-        arenadirs.first(li);
-
-      for( ; li.ok() ; li++ )
+        li = arenadirs.begin();
+      bool temp(robot);
+      
+      for( ; ; ++li )
         {
-        	
-          String* current_dir = li();
+          if( (robot && (li == robotdirs.end() ) ) || (!robot && (li == arenadirs.end() ) ) )
+            break;
+          
+          string current_dir = *li;
           DIR* dir;
+          bool err_in_file = false; // set by called functions but not currently checked here
           
-          
-          if( dir = opendir(current_dir->chars()) )
+          if( dir = opendir(current_dir.c_str()) )
             {
               struct dirent * entry;
               while (NULL != ( entry = readdir( dir ) ) )
                 {
-                  String full_file_name = *current_dir + entry->d_name;
-                  if( ( robot && check_if_filename_is_robot( full_file_name ) ) ||
-                      ( !robot && check_if_filename_is_arena( full_file_name ) ) )
+                  string full_file_name = current_dir + entry->d_name;
+                  if( ( robot && check_if_filename_is_robot( full_file_name, &err_in_file ) ) ||
+                      ( !robot && check_if_filename_is_arena( full_file_name, &err_in_file ) ) )
                     {
                       char* lst[] = { entry->d_name };
 
@@ -215,8 +220,8 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
                       info = new start_tournament_info_t
                         ( row, false,
                           entry->d_name,
-                          current_dir->chars() );
-                      dir_list->insert_last( info );
+                          current_dir.c_str() );
+                      dir_list->push_back( info );
                     }
                 }
               closedir( dir );
@@ -411,6 +416,15 @@ StartTournamentWindow::StartTournamentWindow( const int default_width,
 StartTournamentWindow::~StartTournamentWindow()
 {
   gtk_widget_destroy( window_p );
+  list<start_tournament_info_t*>::const_iterator li;
+  for(li = selected_robot_tournament.begin(); li != selected_robot_tournament.end(); ++li)
+    delete *li;
+  for(li = selected_robot_directory.begin(); li != selected_robot_directory.end(); ++li)
+    delete *li;
+  for(li = selected_arena_tournament.begin(); li != selected_arena_tournament.end(); ++li)
+    delete *li;
+  for(li = selected_arena_directory.begin(); li != selected_arena_directory.end(); ++li)
+    delete *li;
 }
 
 void
@@ -504,7 +518,7 @@ StartTournamentWindow::load_file_selected( GtkWidget* widget,
                                            class StartTournamentWindow* stw_p )
 {
   stw_p->load_tournament_file
-    ( String( gtk_file_selection_get_filename
+    ( string( gtk_file_selection_get_filename
               ( GTK_FILE_SELECTION( stw_p->get_filesel() ) ) ),
       true );
   destroy_filesel( stw_p->get_filesel(), stw_p );
@@ -538,7 +552,7 @@ StartTournamentWindow::save_file_selected( GtkWidget* widget,
                                            class StartTournamentWindow* stw_p )
 {
   stw_p->save_tournament_file
-    ( String( gtk_file_selection_get_filename
+    ( string( gtk_file_selection_get_filename
              ( GTK_FILE_SELECTION( stw_p->get_filesel() ) ) ),
       true, true );
   destroy_filesel( stw_p->get_filesel(), stw_p );
@@ -553,7 +567,7 @@ StartTournamentWindow::destroy_filesel( GtkWidget* widget,
 }
 
 void
-StartTournamentWindow::load_tournament_file( const String& full_filename,
+StartTournamentWindow::load_tournament_file( const string& full_filename,
                                              bool display_fail_message )
 {
   if(!parse_tournament_file( full_filename,
@@ -561,10 +575,10 @@ StartTournamentWindow::load_tournament_file( const String& full_filename,
                              StartTournamentWindow::new_tournament_from_tournament_file,
                              this, false ) && display_fail_message )
     {
-      String error_msg( _("Error in specified tournament file.") );
-      List<String> button_list;
-      button_list.insert_last( new String( _(" Ok ") ) );
-      String info_text = (String)_("Tournament could not be loaded.") + String('\n')
+      string error_msg( _("Error in specified tournament file.") );
+      list<string> button_list;
+      button_list.push_back( string( _(" Ok ") ) );
+      string info_text = _("Tournament could not be loaded.") + string(1, '\n')
         + error_msg;
       Dialog( info_text, button_list, 
               (DialogFunction) StartTournamentWindow::dummy_result );
@@ -573,8 +587,8 @@ StartTournamentWindow::load_tournament_file( const String& full_filename,
 
 void
 StartTournamentWindow::new_tournament_from_tournament_file
-( const List<start_tournament_info_t>& robotfilename_list, 
-  const List<start_tournament_info_t>& arenafilename_list, 
+( const list<start_tournament_info_t*>& robotfilename_list, 
+  const list<start_tournament_info_t*>& arenafilename_list, 
   const int robots_p_game, const int games_p_sequence, const int n_o_sequences,
   StartTournamentWindow* stw_p )
 {
@@ -584,17 +598,18 @@ StartTournamentWindow::new_tournament_from_tournament_file
 
 void
 StartTournamentWindow::
-new_tournament( const List<start_tournament_info_t>& robotfilename_list, 
-                const List<start_tournament_info_t>& arenafilename_list, 
+new_tournament( const list<start_tournament_info_t*>& robotfilename_list, 
+                const list<start_tournament_info_t*>& arenafilename_list, 
                 const int robots_p_game, 
                 const int games_p_sequence, 
                 const int n_o_sequences )
 {
-
+ try
+  {
   for( int i = 0; i<2; i++ )
     {
       GtkWidget* tour_clist;
-      List<start_tournament_info_t>* tour_list;
+      list<start_tournament_info_t*>* tour_list;
       bool robot;
       if( i == 0 )
         {
@@ -610,13 +625,15 @@ new_tournament( const List<start_tournament_info_t>& robotfilename_list,
         }
 
       gtk_clist_clear( GTK_CLIST( tour_clist ) );
-      tour_list->delete_list();
+      list<start_tournament_info_t*>::const_iterator li2;
+      for(li2 = tour_list->begin(); li2 != tour_list->end(); ++li2)
+        delete *li2;
+      tour_list->clear();
 
-      ListIterator<start_tournament_info_t> li;
-      for( ( robot ? robotfilename_list.first(li) : arenafilename_list.first(li) );
-             li.ok(); li++ )
+      list<start_tournament_info_t*>::const_iterator li;
+      for( robot ? li = robotfilename_list.begin() : li = arenafilename_list.begin(); (!robot || li != robotfilename_list.end()) && (robot || li != arenafilename_list.end()); ++li)
         {
-          start_tournament_info_t* info = li();
+          start_tournament_info_t* info = *li;
 
           char* lst[] = { "" };
 
@@ -627,29 +644,39 @@ new_tournament( const List<start_tournament_info_t>& robotfilename_list,
                                     the_gui.get_bg_gdk_colour_p());
 
       
-          String fname = info->filename;
-          fname = get_segment( fname, fname.find( '/', 0, true ) + 1, -1 );
+          string fname = info->filename;
+          fname = fname.substr(fname.rfind( '/', fname.size() ) + 1);
       
           gtk_clist_set_text( GTK_CLIST( tour_clist ),
-                              row, 0, fname.chars() );
+                              row, 0, fname.c_str() );
           info->selected = false;
           info->row = row;
-          tour_list->insert_last( new start_tournament_info_t
+          tour_list->push_back( new start_tournament_info_t
                                   ( info->row, false, info->filename, info->directory ) );
         }
     }
-  gtk_entry_set_text( GTK_ENTRY( entries[1] ), String(robots_p_game).chars() );
-  gtk_entry_set_text( GTK_ENTRY( entries[0] ), String(games_p_sequence).chars() );
-  gtk_entry_set_text( GTK_ENTRY( entries[2] ), String(n_o_sequences).chars() );
+   }
+  catch(exception& e)
+    {
+      Error(true, e.what(), "StartTournamentWindow::new_tournament");
+    }
+  ostringstream robots_p_game_str, games_p_sequence_str, n_o_sequences_str;
+  robots_p_game_str << robots_p_game;
+  games_p_sequence_str << games_p_sequence;
+  n_o_sequences_str << n_o_sequences;
+  gtk_entry_set_text( GTK_ENTRY( entries[1] ), robots_p_game_str.str().c_str() );
+  gtk_entry_set_text( GTK_ENTRY( entries[0] ), games_p_sequence_str.str().c_str() );
+  gtk_entry_set_text( GTK_ENTRY( entries[2] ), n_o_sequences_str.str().c_str() );
 }
 
 void
-StartTournamentWindow::save_tournament_file( const String& full_filename,
+StartTournamentWindow::save_tournament_file( const string& full_filename,
                                              bool display_file_fail_message,
                                              bool display_tour_fail_message )
 {
   int value[3];
-  int robot_number = get_selected_robot_tournament()->number_of_elements();
+  int robot_number = get_selected_robot_tournament()->size();
+  istringstream string2number;
 
   for( int i = 0; i < 3; i++ )
     {
@@ -660,31 +687,35 @@ StartTournamentWindow::save_tournament_file( const String& full_filename,
         max_value = 10000;
       else
         {
-          max_value = min( the_opts.get_l( OPTION_MAX_ROBOTS_ALLOWED ),robot_number);
+          max_value = min_rtb( the_opts.get_l( OPTION_MAX_ROBOTS_ALLOWED ),robot_number);
         }
       if(i != 1)
         min_value = 1;
       else
         min_value = 2;
 
-      value[i] = str2int( gtk_entry_get_text( GTK_ENTRY( get_entries()[i] ) ) );
+      string2number.clear();
+      string2number.str(gtk_entry_get_text( GTK_ENTRY( get_entries()[i] ) ));
+      int tmp;
+      string2number >> tmp;
+      value[i] = tmp;
 
-      value[i] = min( max_value, value[i] );
-      value[i] = max( min_value, value[i] );
+      value[i] = min_rtb( max_value, value[i] );
+      value[i] = max_rtb( min_value, value[i] );
     }
 
-  ofstream file(full_filename.chars(), ios::out);
+  ofstream file(full_filename.c_str(), ios::out);
   if( robot_number > 1 && file &&
-      !( selected_arena_tournament.is_empty() ) )
+      !( selected_arena_tournament.empty() ) )
     {
       file << "Robots: " << endl;
-      ListIterator<start_tournament_info_t> li;
-      for( selected_robot_tournament.first(li); li.ok(); li++ )
-        file << li()->filename << " " << endl;
+      list<start_tournament_info_t*>::const_iterator li;
+      for( li = selected_robot_tournament.begin(); li != selected_robot_tournament.end(); ++li )
+        file << (*li)->filename << " " << endl;
 
       file << "Arenas: " << endl;
-      for( selected_arena_tournament.first(li); li.ok(); li++ )
-        file << li()->filename << " " << endl;
+      for( li = selected_arena_tournament.begin(); li != selected_arena_tournament.end(); ++li )
+        file << (*li)->filename << " " << endl;
 
       file << "Robots/Sequence: " << value[1] << endl;
       file << "Games/Sequence: " << value[0] << endl;
@@ -692,22 +723,22 @@ StartTournamentWindow::save_tournament_file( const String& full_filename,
     }
   else if( display_file_fail_message || display_tour_fail_message )
     {
-      String error_msg( "" );
+      string error_msg( "" );
       if( display_tour_fail_message )
         {
           if( robot_number <= 1 )
-            error_msg += String('\n') + _("There are too few robots in the tournament.");
-          if( selected_arena_tournament.is_empty() )
-            error_msg += String('\n') + _("There are no arenas in the tournament.");
+            error_msg += string(1, '\n') + _("There are too few robots in the tournament.");
+          if( selected_arena_tournament.empty() )
+            error_msg += string(1, '\n') + _("There are no arenas in the tournament.");
         }
       if( display_file_fail_message && !file )
-        error_msg += String('\n') + _("Could not open file.");
+        error_msg += string(1, '\n') + _("Could not open file.");
 
       if( error_msg != "" )
         {
-          List<String> button_list;
-          button_list.insert_last( new String( _(" Ok ") ) );
-          String info_text = (String)_("Tournament could not be saved.") + error_msg;
+          list<string> button_list;
+          button_list.push_back( string( _(" Ok ") ) );
+          string info_text = string( _("Tournament could not be saved.") ) + error_msg;
           Dialog( info_text, button_list, 
                   (DialogFunction) StartTournamentWindow::dummy_result );
         }
@@ -735,23 +766,26 @@ StartTournamentWindow::set_entry( GtkWidget* widget,
         else
           {
             int number_of_robots = mmf_p->stw_p->
-              get_selected_robot_tournament()->number_of_elements();
+              get_selected_robot_tournament()->size();
             if( number_of_robots > the_opts.get_l( OPTION_MAX_ROBOTS_ALLOWED ) )
               number_of_robots = the_opts.get_l( OPTION_MAX_ROBOTS_ALLOWED );
+            ostringstream number_of_robots_str;
+            number_of_robots_str << number_of_robots;
             gtk_entry_set_text
               ( GTK_ENTRY( mmf_p->stw_p->get_entries()[mmf_p->entry] ),
-                String(number_of_robots).chars() );
+                number_of_robots_str.str().c_str() );
           }
       }
       break;
     case MMF_FULL_ROUND:
       {
         int number_of_robots = mmf_p->stw_p->
-          get_selected_robot_tournament()->number_of_elements();
+          get_selected_robot_tournament()->size();
 
-        int robots_per_sequence = 
-          str2int( gtk_entry_get_text
-                   ( GTK_ENTRY( mmf_p->stw_p->get_entries()[1] ) ) );
+        istringstream string2number(gtk_entry_get_text
+                   ( GTK_ENTRY( mmf_p->stw_p->get_entries()[1] ) ));
+        int robots_per_sequence;
+        string2number >> robots_per_sequence;
 
         if( number_of_robots < robots_per_sequence )
           robots_per_sequence = number_of_robots;
@@ -759,24 +793,28 @@ StartTournamentWindow::set_entry( GtkWidget* widget,
           robots_per_sequence = the_opts.get_l( OPTION_MAX_ROBOTS_ALLOWED );
         if( robots_per_sequence < 2 )
           robots_per_sequence = 2;
+        ostringstream number2string;
+        number2string << min ( 9999, binomial( number_of_robots,
+                                          robots_per_sequence) );
         gtk_entry_set_text
           ( GTK_ENTRY( mmf_p->stw_p->get_entries()[mmf_p->entry] ),
-            String( min ( 9999, binomial( number_of_robots,
-                                          robots_per_sequence) ) ).chars() );
+            number2string.str().c_str() );
       }
       break;
     case MMF_ALL_ARENAS:
       {
         int number_of_arenas = mmf_p->stw_p->
-          get_selected_arena_tournament()->number_of_elements();
+          get_selected_arena_tournament()->size();
 
         if( number_of_arenas > the_opts.get_l( OPTION_MAX_ROBOTS_ALLOWED ) )
           number_of_arenas = the_opts.get_l( OPTION_MAX_ROBOTS_ALLOWED );
         if( number_of_arenas < 1 )
           number_of_arenas = 1;
+        ostringstream number_of_arenas_str;
+        number_of_arenas_str << number_of_arenas;
         gtk_entry_set_text
           ( GTK_ENTRY( mmf_p->stw_p->get_entries()[mmf_p->entry] ),
-            String(number_of_arenas).chars() );
+            number_of_arenas_str.str().c_str() );
       }
       break;
     }
@@ -794,7 +832,8 @@ StartTournamentWindow::start( GtkWidget* widget,
       return;
 
   int value[3];
-  int robot_number = stw_p->get_selected_robot_tournament()->number_of_elements();
+  int robot_number = stw_p->get_selected_robot_tournament()->size();
+  istringstream string2number;
 
   for( int i = 0; i < 3; i++ )
     {
@@ -805,20 +844,24 @@ StartTournamentWindow::start( GtkWidget* widget,
         max_value = 10000;
       else
         {
-          max_value = min(the_opts.get_l( OPTION_MAX_ROBOTS_ALLOWED ),robot_number);
+          max_value = min_rtb(the_opts.get_l( OPTION_MAX_ROBOTS_ALLOWED ),robot_number);
         }
       if(i != 1)
         min_value = 1;
       else
         min_value = 2;
 
-      value[i] = str2int( gtk_entry_get_text( GTK_ENTRY( stw_p->get_entries()[i] ) ) );
+      string2number.clear();
+      string2number.str(gtk_entry_get_text( GTK_ENTRY( stw_p->get_entries()[i] ) ));
+      int tmp;
+      string2number >> tmp;
+      value[i] = tmp;
 
-      value[i] = min( max_value, value[i] );
-      value[i] = max( min_value, value[i] );
+      value[i] = min_rtb( max_value, value[i] );
+      value[i] = max_rtb( min_value, value[i] );
     }
   if( robot_number > 1 &&
-      !( stw_p->get_selected_arena_tournament()->is_empty() ) )
+      !( stw_p->get_selected_arena_tournament()->empty() ) )
     {
       stw_p->set_tournament_started_flag( true );
       the_arena_controller.start_realtime_arena();
@@ -836,17 +879,17 @@ StartTournamentWindow::start( GtkWidget* widget,
     }
   else
     {
-      String error_msg( "" );
+      string error_msg( "" );
       if( robot_number <= 1 )
-        error_msg += String('\n') + _("There must be at least two robots in the tournament.");
-      if( stw_p->selected_arena_tournament.is_empty() )
-        error_msg += String('\n') + _("There are no arenas in the tournament.");
+        error_msg += string(1,'\n') + _("There must be at least two robots in the tournament.");
+      if( stw_p->selected_arena_tournament.empty() )
+        error_msg += string(1,'\n') + _("There are no arenas in the tournament.");
 
       if( error_msg != "" )
         {
-          List<String> button_list;
-          button_list.insert_last( new String( _(" Ok ") ) );
-          String info_text = _("Tournament could not be started.") + error_msg;
+          list<string> button_list;
+          button_list.push_back( string( _(" Ok ") ) );
+          string info_text = _("Tournament could not be started.") + error_msg;
           Dialog( info_text, button_list, 
                   (DialogFunction) StartTournamentWindow::dummy_result );
         }
@@ -885,8 +928,8 @@ StartTournamentWindow::change_all_selection( const bool robots,
                                              const bool dir,
                                              const bool all )
 {
-  ListIterator<start_tournament_info_t> li;
-  List<start_tournament_info_t>* info_list = NULL;
+  list<start_tournament_info_t*>::const_iterator li;
+  list<start_tournament_info_t*>* info_list = NULL;
   GtkWidget * clist = NULL;
 
 
@@ -910,9 +953,9 @@ StartTournamentWindow::change_all_selection( const bool robots,
       info_list = get_selected_arena_tournament();
       clist = get_arenas_in_tournament_clist();
     }
-  for( info_list->first(li); li.ok() ; li++ )
+  for( li = info_list->begin(); li != info_list->end(); ++li )
     {
-      start_tournament_info_t* info_p = li();
+      start_tournament_info_t* info_p = *li;
       if( all )
         {
           info_p->selected = true;
@@ -929,9 +972,9 @@ StartTournamentWindow::change_all_selection( const bool robots,
 void
 StartTournamentWindow::add_all_selected( const bool robots )
 {
-  ListIterator<start_tournament_info_t> li;
-  List<start_tournament_info_t>* info_dir_list;
-  List<start_tournament_info_t>* info_tourn_list;
+  list<start_tournament_info_t*>::const_iterator li;
+  list<start_tournament_info_t*>* info_dir_list;
+  list<start_tournament_info_t*>* info_tourn_list;
   GtkWidget * clist_tourn;
 
   if(robots)
@@ -947,9 +990,9 @@ StartTournamentWindow::add_all_selected( const bool robots )
       clist_tourn = get_arenas_in_tournament_clist();
     }
 
-  for( info_dir_list->first(li) ; li.ok() ; li++ )
+  for( li = info_dir_list->begin(); li != info_dir_list->end() ; ++li )
     {
-      start_tournament_info_t* info_dir_p = li();
+      start_tournament_info_t* info_dir_p = *li;
       if( info_dir_p->selected )
         {
           char * list[] = { "" };
@@ -962,18 +1005,18 @@ StartTournamentWindow::add_all_selected( const bool robots )
 
 
           gtk_clist_set_text( GTK_CLIST( clist_tourn ), row, 0,
-                              info_dir_p->filename.non_const_chars() );
+                              info_dir_p->filename.c_str()/*.non_const_chars()*/ );
       
           start_tournament_info_t* info_tourn_p;
-          String full_filename;
+          string full_filename;
           if(robots)
             full_filename = info_dir_p->directory + info_dir_p->filename;
           else
             full_filename = info_dir_p->directory + info_dir_p->filename;
 
           info_tourn_p = new start_tournament_info_t
-            ( row, false, full_filename.chars(), info_dir_p->directory );
-          info_tourn_list->insert_last( info_tourn_p );
+            ( row, false, full_filename.c_str(), info_dir_p->directory );
+          info_tourn_list->push_back( info_tourn_p );
         }
     }
 }
@@ -981,9 +1024,9 @@ StartTournamentWindow::add_all_selected( const bool robots )
 void
 StartTournamentWindow::remove_all_selected( const bool robots )
 {
-  ListIterator<start_tournament_info_t> li;
-  ListIterator<start_tournament_info_t> li2;
-  List<start_tournament_info_t>* info_dir_list;
+  list<start_tournament_info_t*>::iterator li;
+  list<start_tournament_info_t*>::const_iterator li2;
+  list<start_tournament_info_t*>* info_dir_list;
   GtkWidget * clist_tourn;
 
   if(robots)
@@ -997,22 +1040,25 @@ StartTournamentWindow::remove_all_selected( const bool robots )
       clist_tourn = get_arenas_in_tournament_clist();
     }
 
-  for( info_dir_list->first(li) ; li.ok(); li++ )
+  for( li = info_dir_list->begin() ; li != info_dir_list->end(); )
     {
-      start_tournament_info_t* info_p = li();
+      start_tournament_info_t* info_p = *li;
 
       if( info_p->selected )
         {
           gtk_clist_remove(GTK_CLIST(clist_tourn), info_p->row);
           
-          for( info_dir_list->first(li2); li2.ok(); li2++ )
+          for( li2 = info_dir_list->begin(); li2 != info_dir_list->end(); ++li2 )
             {
-              start_tournament_info_t* info2_p = li2();
+              start_tournament_info_t* info2_p = *li2;
               if(info2_p->row > info_p->row)
                 info2_p->row = info2_p->row - 1;
             }
-          info_dir_list->remove(li);
+          delete *li;
+          li = info_dir_list->erase(li);
         }
+      else
+        ++li;
     }
 }
 
@@ -1024,7 +1070,7 @@ StartTournamentWindow::selection_made( GtkWidget* clist, gint row,
   if( event == NULL )
     return;
 
-  List<start_tournament_info_t>* info_list = NULL;
+  list<start_tournament_info_t*>* info_list = NULL;
 
   if(clist == stw_p->get_robots_in_tournament_clist() )
     info_list = stw_p->get_selected_robot_tournament();
@@ -1045,12 +1091,12 @@ StartTournamentWindow::selection_made( GtkWidget* clist, gint row,
 
 start_tournament_info_t*
 StartTournamentWindow::find_row_in_clist( const int row,
-                                          List<start_tournament_info_t>* info_list )
+                                          list<start_tournament_info_t*>* info_list )
 {
-  ListIterator<start_tournament_info_t> li;
-  for( info_list->first(li); li.ok() ; li++ )
+  list<start_tournament_info_t*>::const_iterator li;
+  for( li = info_list->begin(); li != info_list->end() ; ++li )
     {
-      start_tournament_info_t* info_p = li();
+      start_tournament_info_t* info_p = *li;
       if( info_p->row == row )
         return info_p;
     }
