@@ -23,10 +23,13 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include "IntlDefs.h"
 #include "Gui.h"
 #include "ArenaController.h"
-#include "String.h"
 #include "Various.h"
 #include "Robot.h"
 
+#include <sstream>
+#include <iomanip>
+using namespace std;
+
 //extern class Gui the_gui;
 
 StatisticsWindow::StatisticsWindow( const int default_width,
@@ -73,27 +76,27 @@ StatisticsWindow::StatisticsWindow( const int default_width,
   gtk_widget_show( hbox );
 
   {
-    struct button_t { String label; GtkSignalFunc func; gpointer data; };
+    struct button_t { string label; GtkSignalFunc func; gpointer data; };
 
     struct button_t buttons[] = {
-      { (String)_(" Close "), (GtkSignalFunc) StatisticsWindow::exit,
+      { string( _(" Close ") ), (GtkSignalFunc) StatisticsWindow::exit,
         (gpointer) this },
-      { (String)_(" Save Statistics "), (GtkSignalFunc) StatisticsWindow::save,
+      { string( _(" Save Statistics ") ), (GtkSignalFunc) StatisticsWindow::save,
         (gpointer) this },
-      { (String)_(" Total "), (GtkSignalFunc) StatisticsWindow::change_table_type,
+      { string( _(" Total ") ), (GtkSignalFunc) StatisticsWindow::change_table_type,
         (gpointer) new change_type_data_t( STAT_TYPE_TOTAL, this ) },
-      { (String)_(" Sequence Total "), (GtkSignalFunc) StatisticsWindow::change_table_type,
+      { string( _(" Sequence Total ") ), (GtkSignalFunc) StatisticsWindow::change_table_type,
         (gpointer) new change_type_data_t( STAT_TYPE_SEQUENCE, this ) },
-      { (String)" " + (String)_("Game") + (String)" ",
+      { string( " " ) + string( _("Game") ) + string( " " ),
         (GtkSignalFunc) StatisticsWindow::change_table_type,
         (gpointer) new change_type_data_t( STAT_TYPE_GAME, this ) },
-      { (String)_(" Robot "), (GtkSignalFunc) StatisticsWindow::change_table_type,
+      { string( _(" Robot ") ), (GtkSignalFunc) StatisticsWindow::change_table_type,
         (gpointer) new change_type_data_t( STAT_TYPE_ROBOT, this ) } };
 
     GtkWidget* button_w;
     for( int i=0; i<6; i++ )
       {
-        button_w = gtk_button_new_with_label( buttons[i].label.chars() );
+        button_w = gtk_button_new_with_label( buttons[i].label.c_str() );
         gtk_signal_connect( GTK_OBJECT( button_w ), "clicked",
                             buttons[i].func, buttons[i].data );
         gtk_box_pack_start( GTK_BOX( hbox ), button_w, TRUE, TRUE, 0 );
@@ -444,22 +447,22 @@ StatisticsWindow::change_stats_viewed( GtkWidget* widget,
         the_arena.get_games_per_sequence() + game;
       break;
     case STAT_TYPE_ROBOT:
-      max_nr = the_arena.get_all_robots_in_tournament()->number_of_elements();
+      max_nr = the_arena.get_all_robots_in_tournament()->size();
       break;
     }
 
   if( info_p->extreme_change && max_nr > 0 )
     {
       if( info_p->change < 0 )
-        number = abs( info_p->change );
+        number = abs_rtb( info_p->change );
       else if( info_p->change > 0 )
-        number = max( max_nr - info_p->change + 1, 1 );
+        number = max_rtb( max_nr - info_p->change + 1, 1 );
     }
   else
     {
       number += info_p->change;
-      number = min( number, max_nr );
-      number = max( number, 1 );
+      number = min_rtb( number, max_nr );
+      number = max_rtb( number, 1 );
     }
 
   info_p->sw_p->set_looking_at_nr( number );
@@ -475,14 +478,18 @@ StatisticsWindow::make_title_button()
   gtk_container_add( GTK_CONTAINER( title_button ), title_button_hbox );
   gtk_widget_show( title_button_hbox );
 
-  String title;
+  string title;
   switch( type )
     {
     case STAT_TYPE_TOTAL:
       title = _(" Grand Total ");
       break;
     case STAT_TYPE_SEQUENCE:
-      title = (String) _(" Sequence ") + String( looking_at_nr );
+      {
+        ostringstream number2string;
+        number2string << looking_at_nr;
+        title = string( _(" Sequence ") ) + number2string.str();
+      }
       break;
     case STAT_TYPE_GAME:
       {
@@ -494,8 +501,11 @@ StatisticsWindow::make_title_button()
             game = gps;
             sequence--;
           }
-        title = (String) _(" Sequence: ") + String( sequence ) + "  " +
-          _("Game") + ": " + String( game );
+        ostringstream sequence_str, game_str;
+        sequence_str << sequence;
+        game_str << game;
+        title = string( _(" Sequence: ") ) + sequence_str.str() + "  " +
+          _("Game") + ": " + game_str.str();
       }
       break;
     case STAT_TYPE_ROBOT:
@@ -503,11 +513,11 @@ StatisticsWindow::make_title_button()
         Robot* robot_p;
 
         int i=0;
-        ListIterator<Robot> li;
-        for( the_arena.get_all_robots_in_tournament()->first(li); li.ok(); li++ )
+        list<Robot*>::iterator li;
+        for( li = the_arena.get_all_robots_in_tournament()->begin(); li != the_arena.get_all_robots_in_tournament()->end(); ++li )
           {
             i++;
-            robot_p = li();
+            robot_p = *li;
             if( looking_at_nr == i )
               {
                 GdkPixmap* col_pixmap;
@@ -524,7 +534,7 @@ StatisticsWindow::make_title_button()
       break;
     }
 
-  GtkWidget* label = gtk_label_new( title.chars() );
+  GtkWidget* label = gtk_label_new( title.c_str() );
   gtk_box_pack_start( GTK_BOX( title_button_hbox ), label, TRUE, TRUE, 0 );
   gtk_widget_show( label );
 }
@@ -553,42 +563,54 @@ StatisticsWindow::add_new_row( Robot* robot_p, stat_t average_stat,
       gtk_clist_set_pixmap( GTK_CLIST( clist ), row, 0,
                             colour_pixmap, bitmap_mask );
       gtk_clist_set_text( GTK_CLIST( clist ), row, 1,
-                          robot_p->get_robot_name().non_const_chars() );
+                          robot_p->get_robot_name().c_str()/*non_const_chars()*/ );
     }
 
   if( type == STAT_TYPE_ROBOT)
     {
+      ostringstream sequence_nr_str, game_nr_str;
+      sequence_nr_str << average_stat.sequence_nr;
+      game_nr_str << average_stat.game_nr;
       gtk_clist_set_text( GTK_CLIST( clist ), row, 0,
-                          String( average_stat.sequence_nr ).non_const_chars() );
+                          sequence_nr_str.str().c_str() );
       gtk_clist_set_text( GTK_CLIST( clist ), row, 1,
-                          String( average_stat.game_nr ).non_const_chars() );
+                          game_nr_str.str().c_str() );
     }
 
+  ostringstream position_str;
+  position_str << average_stat.position;
   gtk_clist_set_text( GTK_CLIST( clist ), row, 2,
-                      String( average_stat.position ).non_const_chars() );
+                      position_str.str().c_str() );
 
-  String str;
+  ostringstream points_str;
   if( type == STAT_TYPE_SEQUENCE ||
       type == STAT_TYPE_TOTAL)
-    str = String(average_stat.points, 2, STRING_FIXED_FORM );
+    points_str << setiosflags(ios::fixed) << setprecision(2) << average_stat.points;
   else
-    str = String(average_stat.points );
+    points_str << average_stat.points;
 
-  gtk_clist_set_text( GTK_CLIST( clist ), row, 3, str.non_const_chars() );
+  gtk_clist_set_text( GTK_CLIST( clist ), row, 3, points_str.str().c_str() );
 
   if( type == STAT_TYPE_TOTAL ||
       type == STAT_TYPE_SEQUENCE )
+  {
+      ostringstream games_played_str;
+      games_played_str << games_played;
       gtk_clist_set_text( GTK_CLIST( clist ), row, 4,
-                          String( games_played ).non_const_chars() );
+                          games_played_str.str().c_str() );
+  }
   else
       gtk_clist_set_text( GTK_CLIST( clist ), row, 4,
-                          String( "" ).non_const_chars() );
+                          string( "" ).c_str() );
 
-  gtk_clist_set_text( GTK_CLIST( clist ), row, 5,
-                      String( average_stat.time_survived, 2,
-                              STRING_FIXED_FORM).non_const_chars() );
+  ostringstream time_survived_str;
+  time_survived_str << setiosflags(ios::fixed) << setprecision(2) << average_stat.time_survived;
+  gtk_clist_set_text( GTK_CLIST( clist ), row, 5, time_survived_str.str().c_str() );
+
+  ostringstream total_points_str;
+  total_points_str << average_stat.total_points;
   gtk_clist_set_text( GTK_CLIST( clist ), row, 6,
-                      String( average_stat.total_points ).non_const_chars() );
+                      total_points_str.str().c_str() );
 }
 
 void
@@ -597,8 +619,8 @@ StatisticsWindow::add_the_statistics_to_clist( GtkWidget* widget,
 {
   Robot* robot_p = NULL;
   stat_t* stat_p = NULL;
-  ListIterator<Robot> li;
-  ListIterator<stat_t> stat_li;
+  list<Robot*>::iterator li;
+  list<stat_t*>::const_iterator stat_li;
 
   GtkWidget* clist = sw_p->get_clist();
   stat_types sw_type = sw_p->get_type();
@@ -609,6 +631,7 @@ StatisticsWindow::add_the_statistics_to_clist( GtkWidget* widget,
   gtk_clist_freeze( GTK_CLIST( clist ) );
   gtk_clist_clear( GTK_CLIST( clist ) );
 
+
   switch( sw_type )
     {
     case STAT_TYPE_TOTAL:
@@ -621,20 +644,19 @@ StatisticsWindow::add_the_statistics_to_clist( GtkWidget* widget,
 
         int robot_nr = -1;
 
-        for( the_arena.get_all_robots_in_tournament()->first(li);
-             li.ok(); li++ )
+        for( li = the_arena.get_all_robots_in_tournament()->begin(); li != the_arena.get_all_robots_in_tournament()->end(); ++li )
           {
             robot_nr++;
-            robot_p = li();
+            robot_p = *li;
             points[robot_nr] = 0;
-            for(robot_p->get_statistics()->first(stat_li);
-                stat_li.ok(); stat_li++)
+            for(stat_li = robot_p->get_statistics()->begin();
+                stat_li != robot_p->get_statistics()->end(); ++stat_li)
               {
-                stat_p = stat_li();
+                stat_p = *stat_li;
                 if( ( sw_type == STAT_TYPE_SEQUENCE &&
                       stat_p->sequence_nr == number ) ||
                     sw_type == STAT_TYPE_TOTAL )
-                  points[robot_nr] += stat_li()->points;
+                  points[robot_nr] += (*stat_li)->points;
               }
           }
 
@@ -648,17 +670,16 @@ StatisticsWindow::add_the_statistics_to_clist( GtkWidget* widget,
           }
 
         robot_nr = -1;
-        for( the_arena.get_all_robots_in_tournament()->first(li);
-             li.ok(); li++ )
+        for( li = the_arena.get_all_robots_in_tournament()->begin(); li != the_arena.get_all_robots_in_tournament()->end(); ++li )
           {
             robot_nr++;
-            robot_p = li();
+            robot_p = *li;
             stat_t average_stat(0,0,0,0.0,0.0,0.0);
             int number_of_stat_found = 0;
-            for(robot_p->get_statistics()->first(stat_li);
-                stat_li.ok(); stat_li++)
+            for(stat_li = robot_p->get_statistics()->begin();
+                stat_li != robot_p->get_statistics()->end(); ++stat_li)
               {
-                stat_p = stat_li();
+                stat_p = *stat_li;
                 if( ( sw_type == STAT_TYPE_SEQUENCE &&
                       stat_p->sequence_nr == number ) ||
                     sw_type == STAT_TYPE_TOTAL )
@@ -691,13 +712,14 @@ StatisticsWindow::add_the_statistics_to_clist( GtkWidget* widget,
             sequence--;
           }
 
-        for( the_arena.get_all_robots_in_tournament()->first(li); li.ok(); li++ )
+        for( li = the_arena.get_all_robots_in_tournament()->begin(); li != the_arena.get_all_robots_in_tournament()->end(); ++li )
           {
-            robot_p = li();
+            robot_p = *li;
 
-            for(robot_p->get_statistics()->first(stat_li); stat_li.ok(); stat_li++)
+            for(stat_li = robot_p->get_statistics()->begin();
+                stat_li != robot_p->get_statistics()->end(); ++stat_li)
               {
-                stat_p = stat_li();
+                stat_p = *stat_li;
                 if(stat_p->sequence_nr == sequence &&
                    stat_p->game_nr == game)
                   sw_p->add_new_row( robot_p, *stat_p, -1 );
@@ -709,14 +731,15 @@ StatisticsWindow::add_the_statistics_to_clist( GtkWidget* widget,
       {
         int i=0;
 
-        for( the_arena.get_all_robots_in_tournament()->first(li); li.ok(); li++ )
+        for( li = the_arena.get_all_robots_in_tournament()->begin(); li != the_arena.get_all_robots_in_tournament()->end(); ++li )
           {
             i++;
-            robot_p = li();
+            robot_p = *li;
             if( i == number )
-              for(robot_p->get_statistics()->first(stat_li); stat_li.ok(); stat_li++)
+              for(stat_li = robot_p->get_statistics()->begin();
+                stat_li != robot_p->get_statistics()->end(); ++stat_li)
                 {
-                  stat_p = stat_li();
+                  stat_p = *stat_li;
                   sw_p->add_new_row( robot_p, *stat_p, -1 );
                 }
           }
@@ -804,19 +827,19 @@ StatisticsWindow::row_selected( GtkWidget* clist, gint row,
       gchar* clist_text;
 
       gtk_clist_get_text( GTK_CLIST( clist ), row, column, &clist_text );
-      String robot_name;
+      string robot_name;
       if( clist_text != NULL )
         robot_name = clist_text;
 
-      ListIterator<Robot> li;
+      list<Robot*>::iterator li;
       Robot* robot_p = NULL;
       int counter = 0;
       bool found_robot = false;
-      for( the_arena.get_all_robots_in_tournament()->first(li);
-           li.ok() && !found_robot; li++ )
+      for( li = the_arena.get_all_robots_in_tournament()->begin(); 
+        (li != the_arena.get_all_robots_in_tournament()->end()) && (!found_robot); ++li )
         {
           counter--;
-          robot_p = li();
+          robot_p = *li;
           if( robot_p->get_robot_name() == robot_name )
             {
               found_robot = true;
