@@ -27,7 +27,7 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #ifndef NO_GRAPHICS
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
-#endif 
+#endif
 
 #include <sys/stat.h>
 #if HAVE_DIRENT_H
@@ -47,17 +47,18 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 # endif
 #endif
 #include <stdlib.h>
-//#include <stdio.h>
-#include <string.h>
 #include <iostream>
 #include <fstream>
-# include <dirent.h>
-
+#include <string>
+#include <sstream>
+#include <dirent.h>
+#include <algorithm>
+#include <cctype>
 using namespace std;
 
 #include "Various.h"
 #include "IntlDefs.h"
-#include "String.h"
+#include <string>
 #include "Options.h"
 #include "Structs.h"
 
@@ -65,16 +66,39 @@ extern class Options the_opts;
 #ifndef NO_GRAPHICS
 # include "ControlWindow.h"
 extern class ControlWindow* controlwindow_p;
-#endif 
+#endif
 extern bool no_graphics;
 
 void
-Error(const bool fatal, const String& error_msg, const String& function_name)
+Error(const bool fatal, const string& error_msg, const string& function_name)
 {
+// This code is disabled due to the following reasons:
+// First, if a fatal error occurs, you won't see the error message at all
+// Second: The error function in rtb is called many times even in cases of "warnings", a dialog distracts the user too much
+// Perhaps, we can reenable it again, when point one is saved in a satisfiable manner
+// Note: Making the dialog modal is not an option, because we have timers in the background that will trigger in any case
+
+/*#ifndef NO_GRAPHICS
+
+  string info_text = "Error in " + function_name + ":\n\n" + error_msg + "\n";
+  if( fatal )
+    info_text += "\nFatal Error - program will terminate!";
+  list<string> string_list;
+  string_list.push_back( string( _("Ok") ) );
+  Dialog( info_text, string_list,
+          (DialogFunction) ok_click,
+          "Error" );
+	  
+
+#else
+*/
+
   cerr << "RealTimeBattle: " << _("Error in") << " "
        << function_name << ": " << error_msg << endl;
   //  perror("RealTimeBattle: errno message");
 
+//#endif
+
   if( fatal == true )
     {
       Quit(false);
@@ -92,20 +116,19 @@ Quit(const bool success)
     if( !no_graphics )
       delete controlwindow_p;
   }
-#endif 
+#endif
 
   if( !success )
-    exit(EXIT_FAILURE);  
-      
+    exit(EXIT_FAILURE);
+
   exit(EXIT_SUCCESS);
 }
 
-
 int
 factorial(const int n)
 {
   double fact = 1.0;
-  for(int i=1; i<=n; i++)  
+  for(int i=1; i<=n; i++)
     fact *= i;
 
   if( fact < (double)INT_MAX )
@@ -117,13 +140,13 @@ factorial(const int n)
 int
 binomial(const int n, const int k)
 {
-  int k2 = min(k, n-k);
-  
+  int k2 = min_rtb(k, n-k);
+
   double bin = 1;
-  for(int i=n; i>n-k2; i--)  
+  for(int i=n; i>n-k2; i--)
     bin *= i;
 
-  for(int i=1; i<=k2; i++)  
+  for(int i=1; i<=k2; i++)
     bin /= i;
 
   if( bin < (double)INT_MAX )
@@ -132,7 +155,7 @@ binomial(const int n, const int k)
     return INT_MAX;
 }
 
-void 
+void
 reorder_pointer_array(void** array, int size)
 {
   int n1, n2;
@@ -167,142 +190,253 @@ make_gdk_colour(const long col)
   return colour;
 }
 
-long 
+long
 gdk2hex_colour(const GdkColor& col)
 {
-  return  ( (col.blue & 0xff) | 
+  return  ( (col.blue & 0xff) |
             ((col.green & 0xff) << 8) |
             ((col.red & 0xff) << 16) );
 }
-#endif 
+#endif
 
 void
-read_dirs_from_system(List<String>& robotdirs, List<String>& arenadirs)
+read_dirs_from_system(list<string>& robotdirs, list<string>& arenadirs)
 {
-  String dirs;
+  string dirs;
 
-  robotdirs.delete_list();
-  arenadirs.delete_list();
+  robotdirs.clear();
+  arenadirs.clear();
 
   dirs = the_opts.get_s(OPTION_ROBOT_SEARCH_PATH);
   split_colonseparated_dirs(dirs, robotdirs);
 
 #ifdef ROBOTDIR
-  String * str = new String(ROBOTDIR "/");
-  robotdirs.insert_last( str );
+  string str(ROBOTDIR "/");
+  robotdirs.push_back( str );
 #endif
 
   dirs = the_opts.get_s(OPTION_ARENA_SEARCH_PATH);
   split_colonseparated_dirs(dirs, arenadirs);
 
 #ifdef ARENADIR
-  str = new String(ARENADIR "/");
-  arenadirs.insert_last( str );
+  str = string(ARENADIR "/");
+  arenadirs.push_back( str );
 #endif
 }
 
 // This function splits a string of colonseparated directories into a glist
 void
-split_colonseparated_dirs(String& dirs, List<String>& str_list)
+split_colonseparated_dirs(string& dirs, list<string>& str_list)
 {
-  String current_dir = dirs;
+  string current_dir = dirs;
   int pos, lastpos = 0;
-  while( (pos = dirs.find(':', lastpos)) != -1 )
-    {
-      current_dir = get_segment(dirs, lastpos, pos-1);
-      if(current_dir[current_dir.get_length() - 1] != '/')
-        current_dir += '/';
+  try 
+  {
+    while( (pos = dirs.find(':', lastpos)) != -1 )
+      {
+        current_dir = string( dirs.substr(lastpos, pos-lastpos));
+        if(current_dir.at(current_dir.size() - 1) != '/')
+          current_dir += '/';
 
-      String* str = new String(current_dir);
-      str_list.insert_last( str );
+        string str(current_dir);
+        str_list.push_back( str );
 
-      lastpos = pos+1;
-    }
+        lastpos = pos+1;
+      }
+  
+    if(current_dir != "")
+      {
+        current_dir = dirs.substr(lastpos, dirs.size()-lastpos);
+        if(current_dir.at(current_dir.size() - 1) != '/')
+          current_dir += '/';
 
-  if(current_dir != "")
-    {
-      current_dir = get_segment(dirs, lastpos, -1); 
-      if(current_dir[current_dir.get_length() - 1] != '/')
-        current_dir += '/';
-
-      String* str = new String(current_dir);
-      str_list.insert_last( str );
-    }
+        string str(current_dir);
+        str_list.push_back( str );
+      }
+  }
+  catch(exception& e)
+  {
+    Error(true, e.what(), "split_colonseparated_dirs");
+  }
 }
 
 bool
-check_if_filename_is_robot( String& fname )
-{ 
+check_if_filename_is_robot(const string& fname, bool* err_in_file ) // err_in_file not currently used
+{
   struct stat filestat;
-  if( stat( fname.chars(), &filestat ) != 0 ) 
+  if( stat( fname.c_str(), &filestat ) != 0 )
     return false;
 
 
-  // Check if file is a regular file that can be executed and ends with .robot
-  if( S_ISREG( filestat.st_mode) && 
-      ( filestat.st_mode & ( S_IXOTH | S_IXGRP | S_IXUSR )) &&
-      ( String(".robot") == get_segment(fname, -6, -1) ) )
-    return true;
+  // Check if file is a regular file that can be executed and ends with .robot (or .robot.exe for cygwin)
+  try
+    {
+      if( S_ISREG( filestat.st_mode) &&
+        ( filestat.st_mode & ( S_IXOTH | S_IXGRP | S_IXUSR )) &&
+#ifdef __CYGWIN__
+        ( string(".robot") == fname.substr(fname.size()-6, 6) ||
+          string(".robot.exe") == fname.substr(fname.size()-10, 10) ) )
+
+#else
+        ( string(".robot") == fname.substr(fname.size()-6, 6) ) )
+#endif
+      return true;
+    }
+  catch(exception& e)
+    {
+    Error(true, e.what(), "check_if_filename_is_robot");
+    }
 
 
   return false;
 }
 
 bool
-check_if_filename_is_arena( String& fname )
+check_if_filename_is_arena( string& fname, bool* err_in_file)
+{
+  bool retval = false;
+  struct stat filestat;
+  try
+    {
+      if( 0 == stat( fname.c_str(), &filestat ) && fname.size() > 6 )
+        // Check if file is a regular file that is readable and ends with .arena
+        if( S_ISREG( filestat.st_mode) &&
+            ( filestat.st_mode & ( S_IROTH | S_IRGRP | S_IRUSR ) )  &&
+            ( string(".arena") == fname.substr(fname.size()-6,6) ) )
+        {
+          // So far so good. Now do a rudimentary sanity check.
+          ifstream fin( fname.c_str() );
+          char text[20];
+          fin.get(text, 7);
+          if( 0 == strcmp(text, "scale " ) )
+            retval = true;
+          else
+          {
+            Error(false, "Error in arenafile '" + fname + "': 'scale' not first command. Skipping file.",
+                  "Various::check_if_filename_is_arena");
+            *err_in_file = true;
+          }
+          fin.close();
+        }
+    }
+  catch(exception& e)
+    {
+    Error(true, e.what(), "check_if_filename_is_arena");
+    }
+
+  return retval;
+}
+
+bool
+check_logfile( string& fname )
 {
   struct stat filestat;
-  if( 0 == stat( fname.chars(), &filestat ) && fname.get_length() > 6 )
-    // Check if file is a regular file that is readable and ends with .arena
+  if( 0 == stat( fname.c_str(), &filestat ) )
+    // Check if file is a regular and readable file
     if( S_ISREG( filestat.st_mode) &&
-        ( filestat.st_mode & ( S_IROTH | S_IRGRP | S_IRUSR ) )  &&
-        ( String(".arena") == get_segment(fname, -6, -1) ) )
-      return true;
+        ( filestat.st_mode & ( S_IROTH | S_IRGRP | S_IRUSR ) ) )
+    {
+      // So far so good. Now do a rudimentary sanity check.
+      ifstream fin( fname.c_str() );
+      long line = 0;
+      for(;;)
+      {
+        char buffer[200];
+        fin.getline(buffer, 200);
+        if( fin.eof() )
+        {
+          fin.close();
+          return true;
+        }
 
-  return false;
+        line++;
+        switch(buffer[0])
+        {
+          case 'H':
+            if( 1 != line )
+            {
+              Error(false, "Header not first line in logfile!", "Various::check_logfile");
+              return false;
+            }
+          case 'A':
+          case 'G':
+          case 'O':
+          case 'L':
+          case 'R':
+          case 'T':
+          case 'P':
+          case 'C':
+          case 'M':
+          case 'S':
+          case 'D':
+            // Ok
+            break;
+          default:
+            if( 1 == line )
+              Error(false, "No header found in logfile!", "Various::check_logfile");
+            else
+            {
+              ostringstream number2string;
+              number2string << line;
+              Error(false, "Unrecognized first letter in logfile line " + number2string.str() + ": " + string(1,buffer[0]),
+                     "Various::check_logfile");
+            }
+            fin.close();
+            return false;
+        }
+      }
+    }
 }
 
 void
-check_for_robots_and_arenas( String& word, 
-                             List<start_tournament_info_t>& tour_list,
-                             List<String>& dir_list, 
+check_for_robots_and_arenas( string& word,
+                             list<start_tournament_info_t*>& tour_list,
+                             list<string>& dir_list,
                              const bool check_robots )
 {
   bool found = false;
-  String full_file_name = "";
-
-  if( word.get_length() > 1 )
-    if( get_segment( word, -2, -1 ) == "/*" )
-      {
-        search_directories( get_segment( word, 0, -2 ), tour_list, check_robots );
-        return;
-      }
-  if( word.get_length() == 1 && word[0] == '*' )
+  bool err_in_file = false;
+  string full_file_name = "";
+  try
     {
-      
-      ListIterator<String> li;
-      for( dir_list.first(li); li.ok(); li++ )
-        search_directories( *li(), tour_list, check_robots );
+      if( word.size() > 1 )
+        if( word.substr(word.size()-2, 2 ) == "/*" )
+          {
+            search_directories( word.substr(0, word.size()-1), tour_list, check_robots );
+            return;
+          }
+    }
+  catch(exception& e)
+    {
+      Error(true, e.what(), "check_for_robots_and_arenas");
+    }
+  if( word.size() == 1 && word[0] == '*' )
+    {
+
+      list<string>::const_iterator li;
+      for( li = dir_list.begin(); li != dir_list.end(); ++li )
+        search_directories( *li, tour_list, check_robots );
       return;
     }
   if( word.find('/') != -1 )
     {
-      if((check_robots && check_if_filename_is_robot( word )) ||
-         (!check_robots && check_if_filename_is_arena( word )))
+      if((check_robots && check_if_filename_is_robot( word, &err_in_file )) ||
+         (!check_robots && check_if_filename_is_arena( word, &err_in_file )))
         {
           full_file_name = word;
           found = true;
         }
     }
+//  if( !found && !err_in_file )
   if( !found )
     {
-      ListIterator<String> li;
-      for( dir_list.first(li); li.ok(); li++ )
+      list<string>::const_iterator li;
+      for( li = dir_list.begin(); li != dir_list.end(); ++li )
         {
-          String temp_name = *li() + word;
+          string temp_name = *li + word;
 
-          if((check_robots && check_if_filename_is_robot( temp_name )) ||
-             (!check_robots && check_if_filename_is_arena( temp_name )))
+          if((check_robots && check_if_filename_is_robot( temp_name, &err_in_file )) ||
+             (!check_robots && check_if_filename_is_arena( temp_name, &err_in_file )))
             {
               full_file_name= temp_name;
               found = true;
@@ -314,9 +448,9 @@ check_for_robots_and_arenas( String& word,
     {
       start_tournament_info_t* info;
       info = new start_tournament_info_t(0, false, full_file_name, "");
-      tour_list.insert_last( info );
+      tour_list.push_back( info );
     }
-  else
+  else if(!err_in_file)
     {
       if(check_robots)
         cerr << "Couldn't find an executable robot with filename " << word << endl;
@@ -326,27 +460,28 @@ check_for_robots_and_arenas( String& word,
 }
 
 void
-search_directories( String directory, 
-                    List<start_tournament_info_t>& tour_list,
+search_directories( string directory,
+                    list<start_tournament_info_t*>& tour_list,
                     const bool check_robots )
 {
+  bool err_in_file = false;
   DIR* dir;
-  if( NULL != ( dir = opendir(directory.chars()) ) )
+  if( NULL != ( dir = opendir(directory.c_str()) ) )
     {
       struct dirent* entry;
       while( NULL != ( entry = readdir( dir ) ) )
         {
-          String full_file_name = directory + entry->d_name;
+          string full_file_name = directory + entry->d_name;
           bool res = false;
           if(check_robots)
-            res = check_if_filename_is_robot(full_file_name);
+            res = check_if_filename_is_robot(full_file_name, &err_in_file);
           else
-            res = check_if_filename_is_arena(full_file_name);
+            res = check_if_filename_is_arena(full_file_name, &err_in_file);
           if(res)
             {
               start_tournament_info_t* info;
               info = new start_tournament_info_t(0, false, full_file_name, "");
-              tour_list.insert_last( info );
+              tour_list.push_back( info );
             }
         }
       closedir(dir);
@@ -354,15 +489,15 @@ search_directories( String directory,
 }
 
 bool
-parse_tournament_file( const String& fname, const StartTournamentFunction function,
+parse_tournament_file( const string& fname, const StartTournamentFunction function,
                        void* data, bool fatal_error_on_file_failure )
 {
-  List<String> robotdirs;
-  List<String> arenadirs;
+  list<string> robotdirs;
+  list<string> arenadirs;
 
   read_dirs_from_system(robotdirs, arenadirs);
 
-  ifstream file(fname.chars());
+  ifstream file(fname.c_str());
   if( !file )
     {
       if( fatal_error_on_file_failure )
@@ -376,19 +511,20 @@ parse_tournament_file( const String& fname, const StartTournamentFunction functi
   int robots_p_s = 2;
   int n_o_sequences = 1;
   int looking_for = 0; // 0 = keyword, 1 = robot, 2 = arena
+  istringstream string2number;
 
-  List<start_tournament_info_t> robot_list;
-  List<start_tournament_info_t> arena_list;
+  list<start_tournament_info_t*> robot_list;
+  list<start_tournament_info_t*> arena_list;
 
   for(;;)
     {
       char buffer[200];
       if ((file >> buffer).eof()){
-          
-          
-          int robots_counted = robot_list.number_of_elements();
-          int arenas_counted = arena_list.number_of_elements();
-          
+
+
+          int robots_counted = robot_list.size();
+          int arenas_counted = arena_list.size();
+
           if (games_p_s == -1)
             games_p_s = arenas_counted;
 
@@ -398,85 +534,114 @@ parse_tournament_file( const String& fname, const StartTournamentFunction functi
           if (n_o_sequences == -1)
             n_o_sequences=binomial(robots_counted, games_p_s);
 
-          robots_p_s = min(robots_counted,robots_p_s);
-          
+          robots_p_s = min_rtb(robots_counted,robots_p_s);
+
           if(robots_p_s < 2)
             {
-              if( fatal_error_on_file_failure )
-                Error(true, "Can't start tournament with only " + String(robots_p_s) + 
-                      " robots per sequence", 
+              if( fatal_error_on_file_failure ) 
+              {
+                ostringstream number2string;
+                number2string << robots_p_s;
+                Error(true, "Can't start tournament with only " + number2string.str() +
+                      " robots per sequence",
                       "parse_tournament_file");
+              }
               else
                 return false;
             }
 
           if(games_p_s < 1)
             {
-              if(fatal_error_on_file_failure)
-                Error(true, "Must have at least one game per sequence. " 
-                      "Current value is: " + String(games_p_s),
+              if(fatal_error_on_file_failure) 
+              {
+                ostringstream number2string;
+                number2string << games_p_s;
+                Error(true, "Must have at least one game per sequence. "
+                      "Current value is: " + number2string.str(),
                       "parse_tournament_file");
+              }
               else
                 return false;
             }
 
           if(n_o_sequences < 1)
             {
-              if(fatal_error_on_file_failure)
-                Error(true, "Must have at least one sequence. Current value is: " + 
-                      String(n_o_sequences),
+              if(fatal_error_on_file_failure) 
+              {
+                ostringstream number2string;
+                number2string << n_o_sequences;
+                Error(true, "Must have at least one sequence. Current value is: " +
+                      number2string.str(),
                       "parse_tournament_file");
+              }
               else
                 return false;
             }
 
           // Startup the tournament
 
-          (*function)( robot_list, arena_list, robots_p_s, 
+          (*function)( robot_list, arena_list, robots_p_s,
                        games_p_s, n_o_sequences, data );
 
           return true;
         }
 
-      String word(buffer);
+      string word(buffer);
+      string word_lower;
+      word_lower.resize(word.size());
+      transform (word.begin(),word.end(), word_lower.begin(), (int(*)(int))tolower);
 
-      if((make_lower_case(word) == "games/sequence:") || 
-         (make_lower_case(word) == "g/s:"))
+      if((word_lower == "games/sequence:") ||
+         (word_lower == "g/s:"))
         {
           looking_for = 0;
           file >> buffer;
           if( buffer[0] == '*' )
             games_p_s = -1;
           else
-            games_p_s = str2int( buffer );
+            {
+              string2number.clear();
+              string2number.str(buffer);
+              string2number >> games_p_s;
+            }
         }
-      else if((make_lower_case(word) == "robots/sequence:") || 
-              (make_lower_case(word) == "r/s:"))
+      else if((word_lower == "robots/sequence:") ||
+              (word_lower == "r/s:"))
         {
           looking_for = 0;
           file >> buffer;
           if( buffer[0] == '*' )
             robots_p_s = -1;
           else
-            robots_p_s = str2int( buffer );
+          {
+            string2number.clear();
+            string2number.str(buffer);
+            string2number >> robots_p_s;
+          }
         }
-      else if((make_lower_case(word) == "sequences:") || 
-              (make_lower_case(word) == "seq:"))
+      else if((word_lower == "sequences:") ||
+              (word_lower == "seq:"))
         {
           looking_for = 0;
           file >> buffer;
           if( buffer[0] == '*' )
             n_o_sequences = -1;
           else
-            n_o_sequences = str2int( buffer );
+          {
+            string2number.clear();
+            string2number.str(buffer);
+            string2number >> n_o_sequences;
+          }
         }
-      else if((make_lower_case(word) == "robots:") || (make_lower_case(word) == "r:"))
+      else if((word_lower == "robots:") ||
+              (word_lower == "r:"))
         looking_for = 1;
-      else if((make_lower_case(word) == "arenas:") || (make_lower_case(word) == "a:"))
+      else if((word_lower == "arenas:") ||
+              (word_lower == "a:"))
         looking_for = 2;
       else
         {
-        
+
           switch(looking_for)
             {
             case 0:
@@ -498,10 +663,10 @@ parse_tournament_file( const String& fname, const StartTournamentFunction functi
 void
 create_tmp_rtb_dir()
 {
-  String dirname = the_opts.get_s( OPTION_TMP_RTB_DIR );
+  string dirname = the_opts.get_s( OPTION_TMP_RTB_DIR );
   struct stat filestat;
-  if( 0 != stat( dirname.chars(), &filestat ) ) 
-    mkdir( dirname.chars(), S_IRWXU | S_IRWXG | S_IRWXO );
+  if( 0 != stat( dirname.c_str(), &filestat ) )
+    mkdir( dirname.c_str(), S_IRWXU | S_IRWXG | S_IRWXO );
 }
 
 #ifndef NO_GRAPHICS
@@ -509,18 +674,18 @@ create_tmp_rtb_dir()
 void
 entry_handler( GtkWidget * entry, entry_t * entry_info )
 {
-  String entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
-  String old_entry_text = entry_text;
+  string entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
+  string old_entry_text = entry_text;
   bool point_found = false;
 
-  for(int i=0;i<entry_text.get_length();i++)
-    {
+  try {
+    for(int i=0;i<entry_text.size();i++) {
       switch( entry_info->datatype )
         {
         case ENTRY_INT:
           if( !((entry_text[i] >= '0' && entry_text[i] <= '9') ||
                 (entry_text[i] == '-' && i == 0 && entry_info->allow_sign ))  )
-            entry_text.erase(i);
+            entry_text.erase(i,1);
           break;
         case ENTRY_DOUBLE:
         /* if( !((entry_text[i] >= '0' && entry_text[i] <= '9') ||
@@ -533,11 +698,11 @@ entry_handler( GtkWidget * entry, entry_t * entry_info )
             entry_text.erase(i);*/
           break;
         case ENTRY_HEX:
-          if( !(((entry_text[i] >= '0' && entry_text[i] <= '9') || 
+          if( !(((entry_text[i] >= '0' && entry_text[i] <= '9') ||
                  (entry_text[i] >= 'a' && entry_text[i] <= 'f') ||
                  (entry_text[i] >= 'A' && entry_text[i] <= 'F')) ||
                 (entry_text[i] == '-' && i == 0 ) && entry_info->allow_sign ) )
-            entry_text.erase(i);
+            entry_text.erase(i,1);
           break;
         case ENTRY_CHAR:
           break;
@@ -545,9 +710,13 @@ entry_handler( GtkWidget * entry, entry_t * entry_info )
           break;
         }
     }
-
+  }
+  catch(exception& e) {
+    Error(true, e.what(), "entry_handler");
+  }
+ 
   if(old_entry_text != entry_text)
-    gtk_entry_set_text(GTK_ENTRY(entry),entry_text.chars());
+    gtk_entry_set_text(GTK_ENTRY(entry),entry_text.c_str());
 }
 
 gint
@@ -570,7 +739,7 @@ int_compare(GtkCList* clist, gconstpointer ptr1, gconstpointer ptr2)
     default:
       break;
     }
- 
+
   switch (row2->cell[clist->sort_column].type)
     {
     case GTK_CELL_TEXT:
@@ -589,7 +758,11 @@ int_compare(GtkCList* clist, gconstpointer ptr1, gconstpointer ptr2)
   if (!text1)
     return -1;
 
-  return (str2int(text1) - str2int(text2));
+  istringstream text1_c(text1), text2_c(text2);
+  int text1_num, text2_num;
+  text1_c >> text1_num;
+  text2_c >> text2_num;
+  return (text1_num - text2_num);
 }
 
 gint
@@ -612,7 +785,7 @@ float_compare(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
     default:
       break;
     }
- 
+
   switch (row2->cell[clist->sort_column].type)
     {
     case GTK_CELL_TEXT:
@@ -631,8 +804,10 @@ float_compare(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
   if (!text1)
     return -1;
 
-  double n1 = str2dbl(text1);
-  double n2 = str2dbl(text2);
+  istringstream text1_c(text1), text2_c(text2);
+  double n1, n2;
+  text1_c >> n1;
+  text2_c >> n2;
 
   if(n1 > n2)
     return 1;
@@ -662,7 +837,7 @@ string_case_sensitive_compare(GtkCList *clist, gconstpointer ptr1, gconstpointer
     default:
       break;
     }
- 
+
   switch (row2->cell[clist->sort_column].type)
     {
     case GTK_CELL_TEXT:
@@ -704,7 +879,7 @@ string_case_insensitive_compare(GtkCList *clist, gconstpointer ptr1, gconstpoint
     default:
       break;
     }
- 
+
   switch (row2->cell[clist->sort_column].type)
     {
     case GTK_CELL_TEXT:
